# How to go incognito in Chrome, Edge, Firefox, and Safari
## While incognito mode in any of the big four web browsers offers a measure of privacy, it doesn’t completely hide your tracks online. Here’s how the feature works in each browser, and how to use it.
## Information:

+ Link: https://www.computerworld.com/article/3356840/how-to-go-incognito-in-chrome-firefox-safari-and-edge.html
+ Source: Computerworld
+ Author: Gregg Keizer
+ Date published: 29 November 2023, 03:00
+ Date scraped: 30 November 2023, 21:02

## Article:
![Main article image](https://images.idgesg.net/images/article/2017/09/security-100735073-large.jpg?auto=webp&quality=85,70)


Private browsing. [Incognito](https://www.computerworld.com/article/3186941/you-are-not-very-incognito-in-incognito-mode.html). Privacy mode.

Web browser functions like those trace their roots back more than a decade, and the feature — first found in a top browser in 2005 — spread quickly as one copied another, made tweaks and minor improvements.

But privacy-promising labels can be treacherous. Simply put, going "[incognito](https://www.computerworld.com/article/3292619/the-brave-browser-basics-what-it-does-how-it-differs-from-rivals.html)" is as effective in guarding online privacy as witchcraft is in warding off a common cold.

That's because private browsing is intended to wipe *local* traces of where you've been, what you've searched for, the contents of forms you've filled. It's meant to hide, and not always conclusively at that, your tracks from others with access to the personal computer. That's it.

How to keep web browsing private
--------------------------------

* ### Google Chrome's Incognito mode
* ### Microsoft Edge's private browsing
* ### Mozilla Firefox's Private Browsing mode
* ### Apple's Safari private windows

At their most basic, these features promise that they won't record visited sites to the browsing history, save cookies that show you've been to and logged into sites, or remember credentials like passwords used during sessions. But your traipses through the web are still traceable by Internet providers – and the authorities who serve subpoenas to those entities – employers who control the company network and advertisers who follow your every footstep.

To end that cognitive dissonance, [most browsers have added more advanced privacy tools](https://www.computerworld.com/article/3587752/online-privacy-best-browsers-settings-and-tips.html), generically known as "anti-trackers," which block various kinds of bite-sized chunks of code that advertisers and websites use to trace where people go in attempts to compile digital dossiers or serve targeted advertisements.

Although it might seem reasonable that a browser's end game would be to craft a system that blends incognito modes with anti-tracking, it's highly unlikely. Using either private browsing or anti-tracking carries a cost: site passwords aren't saved for the next visit or sites break under the tracker scrubbing. Nor are those costs equal. It's much easier to turn on some level of anti-tracking by default than it would be to do the same for private sessions, as evidenced by the number of browsers that do the former without complaint while *none* do the latter.

Private browsing will, by necessity, always be a niche, as long as sites rely on cookies for mundane things like log-ins and cart contents.

But the mode remains a useful tool whenever the browser -- and the computer it's on -- are shared. To prove that, we've assembled instructions and insights on using the incognito features -- and anti-tracking tools -- offered by the top four browsers: [Google Chrome](https://www.computerworld.com/article/3343066/a-mac-user-s-guide-to-the-google-chrome-browser.html), Microsoft's Chromium-based [Edge](https://www.computerworld.com/article/3229068/how-to-replace-edge-as-the-default-browser-in-windows-10-and-why-you-shouldnt.html), Mozilla's Firefox and Apple's Safari.


Table of Contents 
* [How to go incognito in Google Chrome](#toc-1)
* [How to privately browse in Microsoft Edge](#toc-2)
* [How to do private browsing in Mozilla Firefox](#toc-3)
* [How to browse privately using Apple's Safari](#toc-4)


Show More 
How to go incognito in Google Chrome
------------------------------------

Although *incognito* may be a synonym to some users for any browser's private mode, Google gets credit for grabbing the word as the feature's snappiest name when it launched the tool in late 2008, just months after Chrome debuted.

The easiest way to open an Incognito window is with the keyboard shortcut combination **Ctrl-Shift-N** (Windows) or **Command-Shift-N** (macOS).

Another way is to click on the menu on the upper right - it's the three vertical dots - and select **New Incognito Window** from the list.

![incognito 1](https://images.idgesg.net/images/article/2020/05/incognito-1-100843143-large.jpg?auto=webp&quality=85,70)


The new Incognito window can be recognized by the dark background and the stylized "spy" icon just to the left of the three-dots menu. Chrome also reminds users of just what Incognito does and doesn't do each time a new window is opened. The message may get tiresome for regular Incognito users, but it may also save a job or reputation; it's important that users remember Incognito doesn't prevent ISPs, businesses, schools and organizations from knowing where customers, workers, students, and others went on the web or what they searched for.

![incognito 2](https://images.idgesg.net/images/article/2020/05/incognito-2-100843144-large.jpg?auto=webp&quality=85,70)


Incognito's introductory screen also displays a toggle -- it's on by default -- along with text that states third-party cookies will be blocked while in the privacy mode. Although cookies are never saved locally as long as the user stays in Incognito, websites have been able to track user movements from site to site *while within Incognito*. Such tracking might be used, for example, to display ads to a user visiting multiple sites in Incognito. This third-party cookie blocking, which halts such behavior, debuted in Chrome 83 in May 2020.

Google has been experimenting with new language on Chrome's Incognito introductory page, but it's yet to make it to the desktop browser. In the Canary build of Chrome on Android, however, the intro now outlines "What Incognito does" and "What Incognito doesn't do," to make the mode's capabilities somewhat clearer to the user. (Some have speculated that the changes were made in reaction to a still-ongoing class-action lawsuit file in 2020 that alleged Google continued to track users' online behavior and movements in Incognito.)

Once a tab in Incognito has been filled with a website, Chrome continues to remind users that they're in Incognito by the dark background of the address bar and window title.

A link on an existing page can be opened directly into Incognito by right-clicking the link, then choosing **Open Link in Incognito Window** from the resulting menu.

[![incognito 3](https://images.idgesg.net/images/article/2020/05/incognito-3-100843145-large.jpg?auto=webp&quality=85,70)](https://images.idgesg.net/images/article/2020/05/incognito-3-100843145-orig.jpg?auto=webp&quality=85,70)


To close an Incognito window, shutter it like any other Chrome window by clicking the X in the upper right corner (Windows) or the red dot in the upper left (macOS).

**Pro tip:** *Google has been working on locking Incognito mode tabs on mobile devices -- the tabs unlocked with built-in biometric features -- so that others can't get a look at the privacy mode's content simply by picking up another's phone or tablet. Google is currently rolling out this feature in Chrome 92 on iOS, and still testing it in preview builds of Chrome for Android. No word on whether desktop Chrome will get something similar.*

How to privately browse in Microsoft Edge
-----------------------------------------

borrowed the name of its private browsing mode, InPrivate, from Internet Explorer (IE), the finally-being-retired legacy browser. InPrivate appeared in IE in March 2009, about three months after Chrome's Incognito and three months before Firefox's privacy mode. When Edge was first released in 2015 and then relaunched as a clone of Chrome in January 2020, InPrivate was part of the package, too.

At the keyboard, the combination of **Ctrl-Shift-N** (Windows) or **Command-Shift-N** (macOS) opens an InPrivate window.

A slower way to get there is to click on the menu at the upper right -- it's three dots arranged horizontally -- and choose **New InPrivate Window** from the menu.

![incognito 10](https://images.idgesg.net/images/article/2020/05/incognito-10-100843151-large.jpg?auto=webp&quality=85,70)


Edge does a more thorough job of explaining what its private browsing mode does and doesn't do than any of its rivals, with on-screen paragraphs dedicated to describing what data the browser collects in InPrivate and how the strictest additional anti-tracking setting can be called on from within the mode. In addition, Edge 92 -- the current version as of this writing -- uses the more informal "What Incognito does" and "What Incognito doesn't do" language on its InPrivate introductory screen, something desktop Chrome hasn't yet gotten to.

Microsoft's browser also well marks InPrivate when the mode is operating: a blue-colored oval marked "In Private" to the right of the address bar combines with a full-black screen to make sure users know where they're at.

![incognito 11](https://images.idgesg.net/images/article/2020/05/incognito-11-100843152-large.jpg?auto=webp&quality=85,70)


It's also possible to launch an InPrivate session by right-clicking a link within Edge and selecting **Open in InPrivate Window**. That option is grayed out when already in a private browsing session but using **Open Link in New Tab** does just that within the current InPrivate frame.

To end InPrivate browsing, simply shut the window by clicking the X in the upper right corner (Windows) or click the red dot at the upper left (macOS).

Although Microsoft based the relaunched Edge on Chromium, the same open-source project that comes up with the code to power Chrome, the Redmond, Wash. company has integrated anti-tracking into its browser, something Chrome has yet to do. Dubbed "Tracking Prevention," it works both in Edge's standard and InPrivate modes.

To set Tracking Prevention, choose **Settings** from the three-ellipses menu at the right, then at the next page, pick **Privacy, Search and Services**. Choose one of the three options -- **Basic, Balanced** or **Strict** -- and make sure the toggle for **Tracking prevention** is in the "on" position. If you want InPrivate to always default to the harshest anti-tracking -- not a bad idea -- toggle **Always use "Strict" tracking prevention when browsing InPrivate** to "on."

![incognito 12](https://images.idgesg.net/images/article/2020/05/incognito-12-100843153-large.jpg?auto=webp&quality=85,70)


**Pro tip:** *To open Edge with InPrivate -- rather than first opening Edge in standard mode, then launching InPrivate -- right-click the Edge icon in the Windows taskbar and select **New InPrivate Window** from the list. There is no similar one-step way to do this in macOS.*

How to do private browsing in Mozilla Firefox
---------------------------------------------

After Chrome trumpeted Incognito, browsers without something similar hustled to catch up. Mozilla added its take -- dubbed Private Browsing -- about six months after Google, in June 2009, with Firefox 3.5.

From the keyboard, a private browsing session can be called up using the combination **Ctrl-Shift-P** (Windows) or **Command-Shift-P** (macOS).

Alternately, a private window will open from the menu at the upper right of Firefox -- three short horizontal lines -- after selecting **New private window**.

![incognito 4](https://images.idgesg.net/images/article/2020/05/incognito-4-100843146-large.jpg?auto=webp&quality=85,70)


A private session window is marked by the purple "mask" icon in the title bar of the Firefox frame. In Windows, the icon is to the left of the minimize/maximize/close buttons; on a Mac, the mask squats at the far right of the title bar. Unlike Chrome and Edge, Firefox does not color-code the top components of the browser window to signify the user is in privacy mode.

Like other browsers, Firefox warns users that private browsing is no cure-all for privacy ills but is limited in what it blocks from being saved during a session. "While this doesn't make you anonymous to websites or your internet service provider, it makes it easier to keep what you do online private from anyone else who uses this computer," the caution reads.

[![Firefox 2021](https://images.idgesg.net/images/article/2021/08/screen-shot-2021-08-30-at-2.06.14-pm-100900955-large.jpg?auto=webp&quality=85,70)](https://images.idgesg.net/images/article/2021/08/screen-shot-2021-08-30-at-2.06.14-pm-100900955-orig.jpg?auto=webp&quality=85,70)


(Firefox also uses the Private Browsing introductory screen to shill the Mozilla VPN service, a $5 to $10 per month virtual private network that can, like other VPNs, hide your actual IP address from destination servers.)

A link can be opened into a Firefox Private Window by right-clicking the link, then choosing **Open Link in New Private Window** from the menu.

To close a Private Window, shut it down just as one would any Firefox window by clicking the X in the upper right corner (Windows) or the red dot in the upper left (macOS).

Notable is that Firefox's private browsing mode is accompanied by the browser's superb "Enhanced Tracking Protection," a suite of tracker blocking tools that stymie all sorts of ad-and-site methods for identifying users, then watching and recording their online behavior. While the earliest version of this was offered only inside Private Windows, the expanded technologies also work within standard mode.

Because Enhanced Tracking Protection is enabled by default within Firefox, it doesn't matter which of its settings -- **Standard, Strict** or **Custom** -- is selected as far as private browsing goes; everything that can be blocked will be blocked.

![incognito 6](https://images.idgesg.net/images/article/2020/05/incognito-6-100843148-large.jpg?auto=webp&quality=85,70)


**Pro tip:** *As of Firefox 91, Private Browsing sessions take place over the more secure HTTPS, not the once-standard HTTP protocol. Users don't need to do anything: The new HTTPS-only policy is on by default. (If the destination site doesn't support HTPPS, Firefox will recognize this and go into fallback mode, connecting via HTTP instead.)*

How to browse privately using Apple's Safari
--------------------------------------------

Chrome may get far more attention for its Incognito than any other browser -- no surprise, since it's by far the most popular browser on the planet -- but Apple's Safari was actually the first to introduce private browsing. The term *private browsing* was first bandied in 2005 to describe Safari 2.0 features that limited what was saved by the browser.

Side note: Early in private browsing, the label *porn mode* was often used as a synonym to describe what many writers and reporters assumed was the primary application of the feature. The term has fallen out of favor.

To open what Safari calls a Private Window on a Mac, users can do a three-key combination of **Command-Shift-N**, the same shortcut Chrome adopted. Otherwise, a window can be called up by selecting the **File** menu and clicking on New Private Window.

![safari incognito 1](https://images.idgesg.net/images/article/2019/03/safari-incognito-1-100790462-large.jpg?auto=webp&quality=85,70)


Safari tags each Private Window by darkening the address bar. It also issues a reminder of what it does -- or more accurately -- what it doesn't do. "Safari will keep your browsing history private for all tabs of this window. After you close this window, Safari won't remember the pages you visited, your search history or your AutoFill information," the top-of-the-page note reads. The warning is more terse than those of other browsers and omits cautions about still-visible online activity.

[![incognito 8](https://images.idgesg.net/images/article/2020/05/incognito-8-100843149-large.jpg?auto=webp&quality=85,70)](https://images.idgesg.net/images/article/2020/05/incognito-8-100843149-orig.jpg?auto=webp&quality=85,70)


Like Firefox, Safari automatically engages additional privacy technologies, whether the user browses in standard or private mode. Safari's Intelligent Tracking Protection (ITP), which kicked off in 2017 and has been repeatedly upgraded since, now blocks all third-party cookies, among other components advertisers and services use to track people as they bounce from one site to another. ITP is controlled by a single on-off switch -- on is the default -- found in **Preferences** under the **Privacy** icon. If the **Website tracking:** box is checked to mark **Prevent cross-site tracking**, ITP is on.

[![incognito 9](https://images.idgesg.net/images/article/2020/05/incognito-9-100843150-large.jpg?auto=webp&quality=85,70)](https://images.idgesg.net/images/article/2020/05/incognito-9-100843150-orig.jpg?auto=webp&quality=85,70)


A link can be opened directly to a Private Window by right-clicking, then selecting **Open Link in New Private Window**. Close a Private Window just as any Safari window, by clicking the red dot in the upper left corner of the browser frame.

**Pro tip:** *Once in a Safari Private Window, opening a new tab -- either by clicking the + icon at the upper right or by using the Command-T key combo -- omits the Private Browsing Enabled notice. (The darkened address bar remains as the sole indicator of a private browsing session.) Other browsers, such as Firefox, repeat their cautionary messages each time a tab is opened in an incognito session.*





## Tags:


### Autogenerated tags:
[[window]] [[firefox]] [[inprivate]] [[windows]] [[google]] [[anti-tracking]] [[mozilla]] [[macos]] [[microsoft]] [[right-clicking]]
