# Is performance tracking about to go mobile?
## Productivity tracking has exploded in the last few years as companies sought to keep track of employee performance. With more workers now remote, that monitoring could soon go mobile.
## Information:

+ Link: https://www.computerworld.com/article/3677855/is-performance-tracking-about-to-go-mobile.html
+ Source: Computerworld
+ Author: Ryan Faas
+ Date published: 26 October 2022, 08:00
+ Date scraped: 07 November 2022, 16:00

## Article:
![Main article image](https://images.techhive.com/images/article/2017/03/spying_tv-100713138-large.jpg?auto=webp&quality=85,70)


Productivity and performance tracking have been [on the rise since the start of the COVID-19 pandemic](https://www.computerworld.com/article/3586616/the-new-normal-when-work-from-home-means-the-boss-is-watching.html) and the shift to remote and hybrid work. Now, as pandemic restrictions recede and more traditional work habits reemerge, it’s inevitable some organizations will want to extend tracking beyond the company PC to mobile devices.

That means IT could soon be involved in selecting, implementing, and supporting productivity and [performance monitoring solutions that keep tabs on workers wherever they are](https://www.computerworld.com/article/3614119/collaboration-analytics-yes-you-can-track-employees-should-you.html) — even if they’re not sitting in front of a computer.

Some collaboration suites offer built-in tracking already — it’s used holistically to identify communication roadblocks, ensure teams work together, find technical or administrative impediments to collaboration, even to help  workers understand their own personal productivity and improve it. These kinds of tools [track usage across devices and platforms](https://www.computerworld.com/article/3613811/cisco-adds-people-insights-analytics-to-webex.html), focusing on interaction with a suite of services instead of an individual PC or device.

For more direct monitoring, software is installed on individual PCs to track basic metrics (sometimes without employee knowledge). These tools track how often a user is physically interacting with a PC, the websites and resources they access — and can even be used to take snapshots from the webcam.

Companies that have invested in these tools in the last few years, and who may want to expand tracking to mobile devices, will have several decisions to make before moving forward with their plans.

One big issue looms. While both iOS and Android are designed for enterprise management, they aren’t designed to offer the same open nature as PCs when it comes to app capability. This is particularly true for managed apps installed by IT (or by the user from an enterprise app catalog) as both Apple and Google have established clear lines between business apps/use and personal apps/data/use.

Here’s what IT can offer the business side when it comes to productivity and performance tracking on mobile and ensuring that any rollout is done right.

## Dealing with trust and employee expectations

Although IT leaders should be prepared to respond if asked to support mobile productivity tracking, they should be cautious about offering to take on this role. It’s a matter of trust.

One of the biggest challenges for enterprise mobility over the past decade or more has been establishing trust with mobile users. I’ve written about this before, most often to note that users who don’t trust IT can (and do) simply not enroll their devices in a mobile management solution. When that occurs, [IT has no visibility into what devices are being used in their organizations](https://www.computerworld.com/article/3544301/amid-the-pandemic-using-trust-to-fight-shadow-it.html), what data is on them — or where that data is going.

Ensuring a secure and effective enterprise mobility strategy requires an active relationship between IT and users, and that requires transparency. Users should understand what IT can and cannot access or track on their devices as well as how any data that’s collected will be used.

That means IT leaders should make sure management understands that there could be [significant pushback if a broad mobile tracking strategy is implemented](https://www.computerworld.com/article/3652513/employee-monitoring-risks-spiraling-out-of-control-union-group-warns.html). They should ensure that there are privacy requirements (mobile devices contain immense amounts of extremely personal information we would never have on work PCs), some of which iOS and Android enforce automatically. They should also make certain that any tracking initiative is codified in a policy and accurately communicated to all mobile users.

My personal view: IT leaders should be prepared to respond to a request to expand tracking to mobile devices *but they shouldn’t offer to do so unless explicitly asked*. Even then, I would focus on the potential for backlash and the security implications of employees who remove their hardware from device management system [because of privacy concerns](https://www.computerworld.com/article/3642712/rise-in-employee-monitoring-prompts-calls-for-new-rules-to-protect-workers.html). (One solution would be for the organization to supply work-only devices to users it wants to track so there’s no confusion or concern about tracking an employee’s personal device or information.)

With those caveats, let’s talk about what mobile productivity and performance tracking can look like.

## Collaboration and productivity suite tracking

The easiest option for productivity and performance tracking on mobile actually isn’t mobile-specific at all. As I noted earlier, many common business suites already have such features. Microsoft 365, Google Workspace, Slack, Webex and others incorporate analytics tools that track use across all devices. This includes workstations, mobile devices and web access from public or personal computers.

This suite-based approach actually gauges usage in the most accurate and effective way because it tracks interaction with enterprise tools regardless of how users are accessing them. This not only captures usage more broadly, it captures use that tracking individual PCs or other devices might well miss, because the reality is that people use multiple tools to access work apps and data throughout the day.

Also, because tracking occurs on the backend, it doesn’t require any additional work to capture data about the use of these apps on mobile hardware (as opposed to work PCs). The functionality is already there and almost certainly already in use if your organization relies on these analytics.

## Tracking specific apps

The next option is to track the use of specific apps. A back-end solution is the easiest option and is particularly effective for in-house apps designed to access another back-end component of some sort. Other business apps that access an enterprise data resource offer the same ability. Much like the suites mentioned above, you’re not actually tracking the device itself — you’re tracking an enterprise resource.

Even apps that exist solely on device can be designed to ping a remote resource or to transmit usage data remotely. Again, the device itself isn’t being asked to track anything.

Beyond this, tracking the use of individual apps varies depending on platform and the MDM solution in use (you’ll need to check with your MDM provider for details).

One option is tracking data usage by app, which can be used as a decent proxy for overall app usage. Where this isn’t an option, you can use a per-app VPN. IT can configure managed apps to use a per-app tunnel to access network resources (something that should be implemented already as a security feature) and the VPN can then be used to track data and  gauge app use.

## Tracking devices via MDM

Although mobile management suites can run queries of an entire device fleet and compile related reports, the primary reason these features exist is to ensure policy compliance, examine the overall health of devices, inventory installed apps and configurations, and determine various security variables. At present, they aren’t really designed to provide advanced productivity and performance tracking. By and large, this leaves productivity analytics in the hands of individual app developers.

This doesn’t mean MDM reports can’t deliver useful information; it just means you won’t get much granularity.

MDM suites can track overall device and data use, the managed or enterprise applications installed on it, and device location. They can also provide detailed information about the device configuration, assignment to users and groups, and enterprise app licensing. As IT configures settings for access to enterprise resources, they can also tie device statistics to those resources.

While this won’t provide a deep trove of productivity data, data usage can be a helpful proxy. What it can do, however, is add a bird’s eye view to productivity tracking and add useful color to other analytics being captured by collaboration and productivity suites, in-house apps and PC-based tracking options. Pulling together these disparate data sources may not be the simplest task, but it is possible to do and automate.

## Why don’t more advanced tracking suites exist?

Given the rise and prevalence of tools for tracking individual, group and organization-level productivity, the lack of more powerful options for mobile may come as a bit of a surprise. After all, if you can enable such expansive tracking on a PC, why not on a smartphone or tablet?

The reason goes back to the design of mobile OSes (as opposed to Windows). To improve security and reliability, iOS and Android significantly sandbox what individual apps are allowed to do and access. There are limited ways for apps to interact and share information with one another. This is by design, and it is one of the factors that make these platforms much more secure than their desktop counterparts. The result is that a single app simply doesn’t have broad access to system logs or processes, limiting its ability to report on anything beyond itself.

As noted, mobile management as a concept was never designed for granular data tracking. The primary function of these suites is security and configuration and they simply haven’t been designed to go beyond the data that’s important for IT to track.

More than that, however, these suites are limited by Apple and Google. If you compare most suites, you’ll find that on-device reporting (as well as configuration and management) functionality is remarkably similar. This is because they are all working with the same set of functions as defined by the companies creating the platforms (they tend to differentiate in areas like their management consoles, integration with other enterprise technologies and support for additional platforms).

Apple and Google have both decided that user privacy is a critical concern when it comes to mobile devices. (Apple has gone so far as to call privacy a human right and make it a key marketing item.) That philosophy has always been baked into their support for enterprise mobility and management. Both, in their individual ways, make a clear distinction between personal and work on managed devices, effectively limiting what management suites can see, access, modify, or delete from managed devices.

Although both companies update MDM functionality and underpinnings with each major OS release, this commitment to separating personal and work contexts, apps, data, connectivity, and monitoring isn’t likely to change. So, while they may expand what IT departments can track, any changes will almost certainly come with carve-outs and limitations. Given that trust is so essential to enterprise mobility success, this isn’t really a bad thing (even if it may be inconvenient).

## Where do companies go from here?

Despite the current limitations on mobile productivity tracking, it’s entirely possible more granular options will possible down the road. Most likely, this would include app usage tracking that becomes more full-featured.

The broadest such expansion would occur if Apple and Google allow MDM to report details on the time spent in apps or how often they’re in use — as long those are managed or enterprise apps (an extension of the features that already exist for individual users to gauge their screen time).

Enterprise app/suite developers could develop common frameworks that make it easy for IT to aggregate data across tools. Or development or management services could emerge that more easily embed usage tracking into apps either directly or through wrapping apps in a management layer before deployment (something common in the early days of mobile app management).

At present, trust and transparency concerns remain the biggest challenge to implementing mobile productivity and performance tracking. There’s no simple solution and it isn’t something a new product release will resolve; this continues to be largely a cultural issue centered on privacy. The general opinion among workers is that advanced tracking represents an invasion of privacy and that some metrics like keystrokes and mouse input don’t accurately reflect productivity.

Devising a holistic solution also remains difficult. With so many different products — collaboration suites, PC-based tracking software, network usage, MDM reports — delivering different data sets (and no way to incorporate all of them), creating a cohesive data dashboard remains difficult. IT departments are best served by focusing on one or two business analytics tools that can be easily deployed — understanding that  trying to reconcile these varied data sources into a coherent report will be hard.

This is an area that has exploded in the past couple of years but there’s no overarching consensus about the best form — and amount — of tracking to deliver actionable insights. It remains unclear what types of tracking are truly valuable. Until that’s settled, IT departments need to remain aware of what’s possible (and what isn’t) as plan for what makes the most sense for their organizations.





## Tags:


### Autogenerated tags:
[[apps]] [[mdm]] [[pcs]] [[google]] [[android]]
