# May's Patch Tuesday update includes 3 zero-day flaws; fix them ASAP
## Microsoft this week rolled out fixes for 51 vulnerabilities in Windows, Microsoft Office, and Visual Studio — including three zero-day flaws that should be patched immediately.
## Information:

+ Link: https://www.computerworld.com/article/3696272/mays-patch-tuesday-update-includes-3-zero-day-flaws-fix-them-asap.html
+ Source: Computerworld
+ Author: Greg Lambert
+ Date published: 11 May 2023, 11:04
+ Date scraped: 16 May 2023, 23:03

## Article:
![Main article image](https://images.idgesg.net/images/article/2020/07/microsoft_windows_updates_cycle_arrows_laptop_mobile_phone_3x2_1200x800-100851684-large.jpg?auto=webp&quality=85,70)


In it's May update, Microsoft addressed 51 vulnerabilities in Windows, Microsoft Office, and Visual Studio. And with three zero-day flaws to urgently address in Windows ([CVE-2023-24932](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-24932), [CVE-2023-29325](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-29325) and [CVE-2023-29336](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-29336)), the focus this month needs to be on rapidly updating both Windows and Microsoft Office. Both platforms get our “Patch Now” recommendation.

Testing for this patch cycle must include validating Windows secure boot, remote desktop and VPN transfers, and ensuring that Microsoft Outlook handles document (RTF and DOC) files correctly. The team at [Application Readiness](https://applicationreadiness.com/) has crafted [this helpful infographic](https://applicationreadiness.com/assurance-security-dashboard-may-2023/) to outline the risks associated with each of the updates for this cycle.

## **Known issues**

Each month, Microsoft includes a list of known issues that relate to the operating system and platforms included in the latest updates. For May, these include:

* After installing the April and/or later updates, Windows devices with some third-party UI customization apps might not launch. [Startallback](https://www.startallback.com/) and [ExplorerPatcher](https://github.com/valinet/ExplorerPatcher) have released a fix for these respective UI issues.
* After installing the May update on guest virtual machines (VMs) running Windows Server 2022, some versions of VMware ESXi, Windows Server 2022 might not start up. Both Microsoft and VMWare are working (together??) on a resolution.

One issue that still affects all versions of Windows 10 (as it hasfor the past three months) is that kiosk device profiles are still not signing in automatically. Microsoft is working on a fix. And for those looking for some redeeming value in gaming updates (who isn't these days?) *Red Dead Redemption 2* is now [reported to be able to start up](https://support.microsoft.com/en-us/topic/april-11-2023-kb5025224-os-build-22000-1817-ebc75372-608d-4a77-a6e0-cb1e15f117fc). Well done.

## **Major revisions**

This month, there have not been any CVEs updated or major revisions to previous patches.

## **Mitigations and workarounds**

Microsoft has not published any further mitigations or workarounds for this month's patches.

## **Testing guidance**

Each month, the team at [Readiness](https://applicationreadiness.com/) analyzes the latest Patch Tuesday updates and provides detailed, actionable testing guidance. The guidance is based on assessing a large application portfolio and a detailed analysis of the Microsoft patches and their potential impact on Windows and application installations.)

Given the large number of system-level changes included this cycle, I have broken down the testing scenarios into standard and high-risk profiles.

 ## **High risk**

Microsoft made significant changes this month to the [TPM Module](https://learn.microsoft.com/en-us/previous-versions/windows/it-pro/windows-8.1-and-8/jj131725(v=ws.11)?redirectedfrom=MSDN), in particular, Secure Boot and BitLocker. The Readiness team suggests the following basic tests for this update:

* Target systems should boot as expected with both Secure Boot and BitLocker enabled.
* Systems should boot (successfully) with BitLocker enabled, and Secure Boot turned off.
* Try the following boot scenarios: USB Boot, DVD Boot, ISO Boot.
* Test your backups after you have updated the secure boot system.
* Ensure that your OS file system restores operate as expected once the update is applied.

We are unsure about the validity of recovery media once this May Patch Tuesday update has been applied. Your boot recovery media might/will fail if made on systems prior to this update. Once you have performed this update you will need to ensure full backups are completed and tested. This scenario affects both Windows 11 (22H2) desktops and Windows Server 2022.

## **Standard risk**

The following changes included in this month's update have not been raised as either high risk tweaks and do not include functional changes.

* Exercise your applications using Microsoft [LDAP](https://learn.microsoft.com/en-us/azure/active-directory/fundamentals/auth-ldap) Connect/Bind Command. Try this using SLL and without.
* The key system file WIN32K.SYS has been updated, which may affect [application menus](https://learn.microsoft.com/en-us/windows/win32/menurc/menus).
* Test applications that set up or configure monitors.
* Test your VMs with Defender Application Guard installed and enabled.
* If you have deployed Microsoft [QUIC](https://techcommunity.microsoft.com/t5/storage-at-microsoft/smb-over-quic-is-ga-and-we-have-lots-of-news/ba-p/2928695), test your connectivity over a VPN to your edge servers. This should include internet surfing, email, file uploads, and video streaming.

All these testing scenarios require significant application-level testing before general deployment. Given the nature of changes included in these patches, the Readiness team recommends that you:

* Test your remote desktop and VPN Connections using [SSTP](https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-sstp/70adc1df-c4fe-4b02-8872-f1d8b9ad806a).
* Test Bluetooth devices (audio and mice).
* Create, read, update, and delete files on an NFS share.
* Test printing jobs (both local and remote).

Automated testing will help with these scenarios (especially using a testing platform that offers a "delta" or comparison between builds). For line-of-business applications that involve getting the application owner (doing [UAT](https://en.wikipedia.org/wiki/Acceptance_testing)) to test and approve the testing results, this is still essential.

## **Windows lifecycle update**

This section includes important changes to servicing (and most security updates) to Windows desktop and server platforms.

* All editions of Windows 10 version 20H2 have reached end of service as of May 9.
* Windows 10 version 21H2 will reach end of service on June 13. Microsoft will continue to service the following editions of Windows 10 21H2: Windows 10 Enterprise and Education, Windows 10 IoT Enterprise, and Windows 10 Enterprise multi-session.

Each month, we break down the update cycle into product families (as defined by Microsoft) with the following basic groupings:

* Browsers (Microsoft IE and Edge);
* Microsoft Windows (both desktop and server);
* Microsoft Office;
* Microsoft Exchange Server;
* Microsoft Development platforms ([ASP.NET](http://asp.net/) Core, .NET Core and Chakra Core);
* Adobe (retired???, maybe next year).

## **Browsers**

Microsoft released 11 low-profile updates to its browser portfolio, all of which have been rated important. For those still using the older code base (IE), the retired out-of-support Internet [Explorer 11 desktop application was permanently turned off](https://techcommunity.microsoft.com/t5/windows-it-pro-blog/internet-explorer-11-desktop-app-retirement-faq/ba-p/2366549) as part of the February Windows security update ("B" release). Add these updates to your standard patch release schedule.

## **Windows**

This month, Microsoft released five critical updates and 22 patches rated important to the Windows platform; they cover the following key components:

* Windows LDAP - Lightweight Directory Access Protocol.
* Windows Network File System.
* Windows Secure Socket Tunneling Protocol (SSTP) and PGM.

At first glance, the [May Windows release](https://www.microsoft.com/en-us/videoplayer/embed/RW11wVP?pid=ocpVideo1-innerdiv-oneplayer&postJsllMsg=true&maskLevel=20&reporting=true&market=en-us) seemed to be pretty light, with a lower-than-normal number of critical updates. However, Microsoft identified and addressed a vulnerability in the Windows secure boot process so complex that a [staged release](https://support.microsoft.com/en-us/topic/kb5025885-how-to-manage-the-windows-boot-manager-revocations-for-secure-boot-changes-associated-with-cve-2023-24932-41a975df-beb2-40c1-99a3-b3ff139f832d) is required. Identified as [CVE-2023-24932](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-24932), Microsoft warns that this vulnerability allows an "attacker to execute self-signed code at the Unified Extensible Firmware Interface (UEFI) level while Secure Boot is enabled."

Yep — you heard that right — your secure boot process has been compromised (brought to you by [Black Lotus](https://en.wikipedia.org/wiki/UEFI)). As mentioned in the testing guidance section above, boot media must be carefully analyzed; otherwise, "[bricked](https://en.wikipedia.org/wiki/Brick_(electronics))" servers are a real possibility. Before proceeding, read this [updated guidance for CVE-2023-24932](https://support.microsoft.com/en-us/topic/kb5025885-how-to-manage-the-windows-boot-manager-revocations-for-secure-boot-changes-associated-with-cve-2023-24932-41a975df-beb2-40c1-99a3-b3ff139f832d), with some further reading on the Black Lotus campaign [available here](https://www.microsoft.com/en-us/security/blog/2023/04/11/guidance-for-investigating-attacks-using-cve-2022-21894-the-blacklotus-campaign/).

Add this update to your "Patch Now" release schedule.

## **Microsoft Office**

Microsoft released one critical update to SharePoint Server this month. In addition to this, six other updates rated important affecting Word, Excel and Teams arrived. The focus needs to be on Microsoft Outlook ([CVE-2023-29324](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-29324)) with an updated patch (to a previous mitigation) to resolve a serious elevation of privilege ([EOP](https://learn.microsoft.com/en-us/dotnet/framework/wcf/feature-details/elevation-of-privilege)) vulnerability. Microsoft published an update(d) [mitigation document](https://msrc.microsoft.com/blog/2023/03/microsoft-mitigates-outlook-elevation-of-privilege-vulnerability/) to explain this serious security issue.

Though the Windows OLE related vulnerability ([CVE-2023-29325](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-29325)) should be included in this month's Windows section, the real problem with this core system library involves how Microsoft Outlook handles [RTF](https://en.wikipedia.org/wiki/Rich_Text_Format) and Word Doc "open" requests. We have not had any reports of these other Microsoft Office related vulnerabilities being exploited in the wild nor any public disclosures for Excel. Given the urgency of these Microsoft Outlook and core Microsoft Office (OLE) patches, add these Office updates to your "Patch Now" release schedule.

## **Microsoft Exchange Server**

Great news: no Exchange Server updates this cycle.

## **Microsoft development platforms**

Microsoft released just two updates this month ([CVE-2023-29338](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-29338) and [CVE-2023-29343](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2023-29343)), both rated important. Affecting only Visual Studio and [Sysmon](https://learn.microsoft.com/en-us/sysinternals/downloads/sysmon) (thank you, [Mark](https://en.wikipedia.org/wiki/Mark_Russinovich))) there is a very low testing profile for either update. Add these updates to your standard developer release schedule.

**Adobe Reader (still here, but not this month)**

Happy Days! No Adobe Reader updates from Microsoft for May.





## Tags:
***CVE's***: CVE-2023-29336 CVE-2023-29338 CVE-2023-29343 CVE-2023-24932 CVE-2023-29324 CVE-2023-29325

### Autogenerated tags:
[[windows]] [[microsoft]] [[cve-2023-24932]] [[vpn]] [[bitlocker]]
