# With a light July Patch Tuesday, it's time to invest in your IT processes
## Though this month's Patch Tuesday update from Microsoft deals with more than 86 reported vulnerabilities, the testing and deployment profile for July should be easy to handle. Use your time wisely.
## Information:

+ Link: https://www.computerworld.com/article/3667375/with-a-light-july-patch-tuesday-its-time-to-invest-in-your-it-processes.html
+ Source: Computerworld
+ Author: Greg Lambert
+ Date published: 15 July 2022, 17:04
+ Date scraped: 15 August 2022, 12:01

## Article:
![Main article image](https://images.idgesg.net/images/article/2020/07/conceptual_representation_of_technical_support_fixes_service_maintenance_updates_digital_sign_wrench_screwdriver_branching_circuits_throughout_system_by_traitov_gettyimages-1199145131_cw_2400x1600-100853239-large.jpg?auto=webp&quality=85,70)


Though we get a reprieve from Exchange updates in this month's Patch Tuesday update, more printer updates are on the way. Even with no updates for Microsoft Exchange or Visual Studio, Adobe is back with 15 critical updates for Adobe Reader. And Microsoft's new patch deployment tool  [Auto-Patch](https://docs.microsoft.com/en-us/windows/deployment/windows-autopatch/overview/windows-autopatch-overview)  is now live. (I always thought application testing was the main problem here, but actually getting patches deployed is still tough.)

Though the numbers are still quite high (with 86+ reported vulnerabilities), the testing and deployment profile for July should be fairly moderate. We suggest taking the time to harden your Exchange Server defenses and mitigation processes, and invest in your testing processes.

You can find more information on the risk of deploying these Patch Tuesday updates [in our helpful infographic](https://applicationreadiness.com/assurance-security-dashboard-july-2022/) .

## Key Testing Scenarios

Given the large number of changes in this July patch cycle, I have broken down the testing scenarios into high-risk and standard-risk groups:

**High Risk:** These changes are likely to include functionality changes, may deprecate existing functionality, and will likely require creating new testing plans.

Core printing functionality has been updated:

* Install and test any new V4 print drivers on a local machine and print.
* Test new V4 printer connections using client and server and print.
* Test existing v4 printer connections
* Ensure GDI rendering and printer drivers generate the expected output

The core changes relate to how Microsoft supports timestamp checking for kernel drivers, so testing applications that require digitally signed binaries is key for this cycle. The big change here is that unsigned drivers should not load. This may cause some application issues or compatibility problems. We recommend a scan of the application portfolio, identifying all applications that depend upon drivers (both signed and unsigned), and generating a test plan that includes installation, application exercising, and uninstall. Having a comparison between pre- and post- patched machines would be helpful, too.

The following changes are not documented as including functional changes, but will still require at least "[smoke testing](https://en.wikipedia.org/wiki/Smoke_testing_(software))" before general deployment:

 * Test scenarios that utilize  [Windows DevicePicker](https://docs.microsoft.com/en-us/uwp/api/Windows.Devices.Enumeration.DevicePicker?view=winrt-22621). Almost impossible to test — as most applications use this common class. If your internally-developed applications pass their basic smoke test, you're fine.
* Test your line of business applications that reference the  [Microsoft mobile CDP](https://docs.microsoft.com/en-us/openspecs/windows_protocols/ms-cdp/929c2238-6d49-4ba4-a36a-37e732c4f736)  APIs. If you have internally developed desktop applications that communicate with mobile devices, a communications check may be required.
* Test connections to the  [rasl2tp server](https://docs.microsoft.com/en-us/windows-hardware/drivers/audio/miniport-driver-types-by-operating-system). This means finding and testing applications that have a dependency on the RAS miniport driver over remote or VPN connections

And  [Curl](https://en.wikipedia.org/wiki/CURL). Specifically, CURL.EXE: — a command line tool for sending files via HTTP protocols (hence "client URL") — has been updated this month.  [Curl for Windows](https://curl.se/windows/)  (the one that is being updated this month) is different from the Open Source project curl. If you are confused why the Curl project team offers this, here's the answer:

"The curl tool shipped with Windows is built by and handled by Microsoft. It is a separate build that will have different features and capabilities enabled and disabled compared to the Windows builds offered by the curl project. They do however build curl from the same source code. If you have problems with their curl version, report that to them. You can probably assume that the curl packages from Microsoft will always lag behind the versions provided by the curl project itself."

With that said, we recommend teams that use the curl command (sourced from the Windows supported branch) give their scripts a quick test run. Microsoft has published a testing scenario matrix that this month includes:

* Use physical machines and virtual machines.
* Use BIOS-based machines and UEFI-enabled machines.
* Use x86, ARM, ARM64, and AMD64 machines.

Note: for each of these testing scenarios, a manual shut-down, reboot and restart is suggested.

## Known Issues

Each month, Microsoft includes a list of known issues that relate to the operating system and platforms included in this update cycle. For July, there are some complex changes to consider:

* Devices with Windows installations created from custom offline media or custom ISO image might have  [Microsoft Edge Legacy](https://support.microsoft.com/microsoft-edge/what-is-microsoft-edge-legacy-3e779e55-4c55-08e6-ecc8-2333768c0fb0)  removed by this update, but not automatically replaced by the new Microsoft Edge.
* After installing the June 21, 2021 ([KB5003690](https://support.microsoft.com/en-us/topic/june-21-2021-kb5003690-os-builds-19041-1081-19042-1081-and-19043-1081-preview-expired-11a7581f-2a01-47d5-ba12-431709ee2248)) update, some devices cannot install new updates, such as the July 6, 2021 ([KB5004945](https://support.microsoft.com/en-us/topic/july-6-2021-kb5004945-os-builds-19041-1083-19042-1083-and-19043-1083-out-of-band-44b34928-0a71-4473-aa22-ecf3b83eed0e)) or later updates. You will receive the error message, "PSFX\_E\_MATCHING\_BINARY\_MISSING." For more information and a workaround, see  [KB5005322.](https://support.microsoft.com/en-us/topic/kb5005322-some-devices-cannot-install-new-updates-after-installing-kb5003214-may-25-2021-and-kb5003690-june-21-2021-66edf7cf-5d3c-401f-bd32-49865343144f)
* After installing this update, IE mode tabs in Microsoft Edge might stop responding when a site displays a modal dialog box. This issue is resolved using  [Known Issue Rollback (KIR)](https://techcommunity.microsoft.com/t5/windows-it-pro-blog/known-issue-rollback-helping-you-keep-windows-devices-protected/ba-p/2176831)  with the following group policy downloads:  [Download for Windows 10, version 20H2 and Windows 10, version 21H1](https://download.microsoft.com/download/8/8/0/88004bea-c83b-4d0c-9ac9-1996644578e9/Windows%2010%2020H2,%2021H1%20and%2021H2%20KB5014023%20220624_22551%20Known%20Issue%20Rollback.msi)  .
* After installing  [KB4493509](https://support.microsoft.com/en-us/topic/april-9-2019-kb4493509-os-build-17763-437-3009e91f-261d-7cdc-4f7e-b00a3fde5991), devices with some Asian language packs installed may receive the error, "0x800f0982 - PSFX\_E\_MATCHING\_COMPONENT\_NOT\_FOUND."

## Major Revisions

This month, Microsoft has not formally published any major revisions or updates to previous patches. There was a kind of “sneaky”  [update from the .NET group](https://devblogs.microsoft.com/dotnet/dotnet-framework-july-2022-security-and-quality-rollup-updates/) that really should have been included in the formal Microsoft documentation update process. However, that update was merely documented support for later versions of Visual Studio.

## Mitigations and Workarounds

Microsoft published one key mitigation for a Windows network vulnerability:

* [CVE-2022-22029](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22029): Windows Network File System Remote Code Execution Vulnerability. Noting that there are no publicly reported exploits for this network vulnerability, Microsoft still recognizes that some administrators may choose to disable  [NFSV3](https://docs.microsoft.com/en-us/windows-server/storage/file-server/ntfs-overview)  before their server systems are fully patched. To disable this network feature, use the PowerShell command. " Set-NfsServerConfiguration -EnableNFSV3 $false." There is no need to disable V4 (as opposed to V3) as the later versions of this protocol are not affected by this security vulnerability.

Each month, we break down the update cycle into product families (as defined by Microsoft) with the following basic groupings:

* Browsers (Microsoft IE and Edge);
* Microsoft Windows (both desktop and server);
* Microsoft Office;
* Microsoft Exchange;
* Microsoft Development platforms (  [ASP.NET](http://asp.net/)  Core, .NET Core and Chakra Core);
* Adobe (retired???, maybe next year).

## Browsers

It just keeps getting better. The downward trend for Microsoft's browser reported vulnerability continues to track ever lower with just two ([CVE-2022-2294](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-2294)  and  [CVE-2022-2295](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-2295)) Chromium updates for this July. Both updates only affect Edge (Chromium) and were released last week. Chrome should automatically update, with our initial analysis showing that both updates will have marginal impact on browser compatibility. You can read about this update on the  [Google Blog](https://chromereleases.googleblog.com/), with the technical details found on  [Git](https://chromium.googlesource.com/chromium/src/+log/105.0.5148.2..105.0.5176.3?pretty=fuller&n=10000). Add these low-profile, low-risk updates to your standard browser release schedule.

## Windows

With just four critical updates and 16 rated important this month, Microsoft is really giving IT admins a bit of a break. The four critical Windows update for this release cycle include:

* [CVE-2022-30221](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-30221): This Windows vulnerability in the core graphics sub-system (GDI) could lead to a remote code execution (RCE) scenario.
* [CVE-2022-22029](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22029)  and  [CVE-2022-22039](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22039): These  [Windows Network file](https://docs.microsoft.com/en-us/windows-server/storage/nfs/nfs-overview)  system issues could result in RCE scenarios on the compromised system.
* [CVE-2022-22038](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22038): This low-level (Win32) RPC component, reported as difficult to exploit, could lead to very difficult troubleshooting scenarios.

All of these critical updates have been officially confirmed as fixed, with no reports of public exploits on Windows desktop systems. The remaining 14 updates are rated important by Microsoft and affect the following Windows systems and components:

* Print driver, Print Spooler and FAX components;
* Hyper-V;
* Windows Kernel and  [Boot Manager](https://docs.microsoft.com/en-us/windows-hardware/drivers/devtest/boot-options-in-windows);
* [Windows Network File system](https://docs.microsoft.com/en-us/windows-server/storage/nfs/nfs-overview), storage and the  [Fast FAT driver](https://docs.microsoft.com/en-us/samples/microsoft/windows-driver-samples/fastfat-file-system-driver/).

Unfortunately, Windows Server 2012 did not fare so well, with reports of  [CVE-2022-22047](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22047)  exploited in the wild. This Windows server vulnerability affects the Client Server Run-Time subsystem ([CRSS](https://docs.microsoft.com/en-us/windows-hardware/drivers/debugger/debugging-csrss)) which is where all the badly behaving user mode drivers hang out. If you have any Windows Server 2012 under your care, this is a "Patch Now" update. Otherwise, add this very low-profile Windows update to your standard release schedule. And don't forget, Microsoft has delivered another Windows 11 update video; [it's found here](https://www.microsoft.com/en-us/videoplayer/embed/RE50TxI?pid=ocpVideo0-innerdiv-oneplayer&maskLevel=20&market=en-us)  .

## Microsoft Office

Microsoft released only two ([CVE-2022-33632](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-33632)  and  [CVE-2022-33633](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-33633)) updates to Microsoft Office this month. Both updates are rated important by Microsoft, and both require local, authenticated privileges to the target system. Add these updates to your standard Office update schedule.

## Microsoft Exchange Server

It's good that we get a break from Microsoft Exchange Server updates. Rather than simply resting, it may be worth investing in your Exchange security infrastructure. Microsoft has provided some major improvements on Exchange during the past year; here are a few ideas on securing your Exchange Server:

* [Microsoft Safety Scanner](https://docs.microsoft.com/en-us/microsoft-365/security/intelligence/safety-scanner-download?view=o365-worldwide): This command line tool is downloaded from Microsoft (must be refreshed every 10 days) and removes malware from your target system. It's not a replacement for third-party tools, but if there is a concern about a machine, this is a good first step.
* [Exchange On-premises Mitigation Tool (EOMT)](https://microsoft.github.io/CSS-Exchange/Security/EOMT/): If you are unable to quickly patch specific Exchange Servers, Microsoft offers a command line to mitigate against known attacks. This PowerShell script will both attempt to remediate as well as mitigate your servers against further attacks — noting that once done, applying patches is the top priority.
* [Exchange Emergency Mitigation Service](https://docs.microsoft.com/en-us/exchange/exchange-emergency-mitigation-service?view=exchserver-2019)  (EM): The Exchange Emergency Mitigation service (EM service) keeps your Exchange Servers secure by applying mitigations/updates/fixes to address any potential threats against your servers. It uses the cloud-based  [Office Config Service](https://config.office.com/)  (OCS) to check for and download available mitigations and will send diagnostic data back to Microsoft.

All of these features and offerings are predicated on using at least Office 2019 — another reason Microsoft has strongly recommended everyone move to Exchange Server 2019 at least. The EM Service was last used in  [March 2021](https://msrc-blog.microsoft.com/2021/03/15/one-click-microsoft-exchange-on-premises-mitigation-tool-march-2021/)  to deal with several Microsoft Exchange vulnerabilities ([CVE-2021-26855](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-26855),  [CVE-2021-26857](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-26857), and  [CVE-2021-26858](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-26858)). These were specific attacks on on-premise servers. It's helpful to know this service is there, but I'm glad it has not been required recently.

## Microsoft Development Platforms

As with Microsoft Exchange, Microsoft has not published any "new" security updates to the Microsoft .NET platform or tools this month. However, there was a problem with  [June's .NET update](https://support.microsoft.com/en-us/topic/june-14-2022-security-and-quality-rollup-for-net-framework-3-5-for-windows-8-1-rt-8-1-and-windows-server-2012-r2-kb5013638-cc66754b-13e5-4328-9933-1e71ff861fd3), which was addressed this month.  [This month's .NET](https://devblogs.microsoft.com/dotnet/dotnet-framework-july-2022-security-and-quality-rollup-updates/)  release resolves the issue that some versions of .NET were not addressed by the previous patch — this is just an informational update. If you are using Microsoft Windows update infrastructure, no further action is required.

## Adobe (really just Reader)

This is a big update from Adobe, with 15 updates rated as critical and seven rated important, all just for Adobe Reader. The critical updates mainly relate to memory issues and could lead to the exercise of arbitrary code on the unpatched system. You can read more about the Adobe bulletin ([APSB22-32](https://helpx.adobe.com/security/products/acrobat/apsb22-32.html)) and Adobe security bulletins  [here](https://helpx.adobe.com/security.html). Add this application specific update to your "Patch Now" release.





## Tags:
***CVE's***: CVE-2021-26855 CVE-2022-22029 CVE-2022-30221 CVE-2021-26858 CVE-2022-33632 CVE-2022-22038 CVE-2022-22047 CVE-2022-22039 CVE-2021-26857 CVE-2022-2294 CVE-2022-2295 CVE-2022-33633

### Autogenerated tags:
[[microsoft]] [[windows]] [[v4]]
