# Zero-day flaws mean it's time to patch Exchange and Windows
## For this month's Patch Tuesday, Microsoft dealt with 84 flaws and a zero-day vulnerability affecting Microsoft Exchange that hasn't yet been fully resolved.
## Information:

+ Link: https://www.computerworld.com/article/3676636/zero-day-flaws-mean-its-time-to-patch-exchange-and-windows.html
+ Source: Computerworld
+ Author: Greg Lambert
+ Date published: 14 October 2022, 17:10
+ Date scraped: 06 November 2022, 14:07

## Article:
![Main article image](https://images.idgesg.net/images/article/2020/07/conceptual_representation_of_technical_support_fixes_service_maintenance_updates_digital_sign_wrench_screwdriver_branching_circuits_throughout_system_by_traitov_gettyimages-1199145131_cw_2400x1600-100853239-large.jpg?auto=webp&quality=85,70)


This month's Patch Tuesday update from Microsoft deals with 84 flaws and a zero-day affecting Microsoft Exchange that at the moment remains unresolved. The Windows updates focus on Microsoft security and networking components with a difficult-to-test update to [COM](https://learn.microsoft.com/en-us/windows/win32/com/the-component-object-model)and [OLE db](https://learn.microsoft.com/en-us/sql/connect/oledb/oledb-driver-for-sql-server?view=sql-server-ver16). And Microsoft browsers get 18 updates—nothing critical or urgent.

That leaves the focus this month on Microsoft Exchange and deploying mitigation efforts, rather than server updates, for the next week. More information about the risks of deploying these Patch Tuesday updates are [available in this infographic](https://applicationreadiness.com/assurance-security-dashboard-october-2022/).

Microsoft continues to improve both its vulnerability reporting and notifications with a new [RSS feed](https://www.bleepingcomputer.com/news/microsoft/microsoft-adds-new-rss-feed-for-security-update-notifications/), and Adobe has followed suit with improved reporting and release documentation. As a gentle reminder,[support for Windows 10 21H1](https://learn.microsoft.com/en-US/lifecycle/announcements/windows-10-21h1-end-of-servicing)ends in December.

## **Key testing scenarios**

Given the large number of changes included this month, I have broken down the testing scenarios into high-risk and standard-risk groups:

**High Risk:**For October, Microsoft has not recorded any high-risk functionality changes. This means it has not made major changes to core APIs or to the functionality to any of the core components or applications included in the Windows desktop and server ecosystems.

More generally, given the broad nature of this update (Office and Windows), we suggest testing the following Windows features and components:

* A GDI update (GDIPLUS.DLL) requires testing of [EMF](https://www.adobe.com/creativecloud/file-types/image/vector/emf-file.html#:~:text=An%20EMF%20file%20is%20a,it%20ideal%20for%20graphics%20printing.), both 16- and 32-bit palette files (opening, printing, and creating).
* Microsoft's [Desktop Application Manager](https://learn.microsoft.com/en-us/windows/client-management/mdm/enterprisedesktopappmanagement-csp)has been updated and will require both provisioning and un-provisioning applications (both install and uninstall testing is required).
* The Windows [CLFS system](https://learn.microsoft.com/en-us/windows-hardware/drivers/kernel/introduction-to-the-common-log-file-system)has been updated to require a short test of creating, reading, updating, and deleting log files.

In addition to these changes and testing requirements, I have included some of the more difficult testing scenarios:

* OLE DB: The venerable Microsoft [OLE DB](https://en.wikipedia.org/wiki/OLE_DB)has been updated and requires all applications with a dependency on SQL Server 2012 or [ADO.NET](http://ado.net/)need to be fully tested before deployment. This Microsoft COM component (OLE DB) separates data from application logic through a set of connections that access data source, session(s), SQL commands, and row-set data.
* Roaming credentials, cryptography keys, and certificates: To find out more about Credential Roaming, check out Microsoft's[Jim Tierney’sposting](https://learn.microsoft.com/en-us/archive/blogs/askds/troubleshooting-credential-roaming)and this great introduction to [Credential Roaming](https://learn.microsoft.com/en-us/archive/blogs/askds/certs-on-wheels-understanding-credential-roaming).
* Encrypted VPN Connections: Microsoft updated the [IKEv2](https://learn.microsoft.com/en-us/windows/security/threat-protection/windows-firewall/securing-end-to-end-ipsec-connections-by-using-ikev2)and [L2TP/IPsec](https://learn.microsoft.com/en-us/troubleshoot/windows-server/networking/configure-l2tp-ipsec-server-behind-nat-t-device)components this month. Testing with remote connections should last longer than eight hours. If you are having trouble with this update, Microsoft has published a[L2TP/IPSec VPN Troubleshooting guide](https://learn.microsoft.com/en-us/troubleshoot/windows-client/networking/l2tp-ipsec-vpn-client-connection-issue?source=recommendations).

Unless otherwise specified, we should now assume each Patch Tuesday update will require testing core printing functions, including:

* printing from directly connected printers;
* large print jobs from servers (especially if they are also domain controllers);
* remote printing (using RDP and VPN).

## **Known issues**

Each month, Microsoft includes a list of known issues that relate to the operating system and platforms included in this update cycle.

* Devices with Windows installations created from custom offline media or a custom ISO image might have [Microsoft Edge Legacy](https://support.microsoft.com/microsoft-edge/what-is-microsoft-edge-legacy-3e779e55-4c55-08e6-ecc8-2333768c0fb0)removed by this update, but not automatically replaced by the new Microsoft Edge. Resolving this issue will require a full/new installation of [Microsoft Edge](https://www.microsoft.com/edge).
* Microsoft SharePoint:This update might [affect some SharePoint 2010 workflow scenarios](https://support.microsoft.com/en-us/topic/sharepoint-2010-workflows-might-be-blocked-by-enhanced-security-policy-kb5020238-eb91e24d-eea4-4490-a281-86503adc8b27). It also generates "6ksbk" event tags in SharePoint Unified Logging System (ULS) logs.

One reported issue with the latest Microsoft Servicing Stack Update ([SSU](https://learn.microsoft.com/en-us/windows/deployment/update/servicing-stack-updates)) [KB5018410](https://support.microsoft.com/en-us/topic/october-11-2022-kb5018410-os-builds-19042-2130-19043-2130-and-19044-2130-6390f057-28ca-43d3-92ce-f4b79a8378fd)is that [Group Policy preferences](https://learn.microsoft.com/en-us/previous-versions/windows/it-pro/windows-server-2012-R2-and-2012/dn581922(v=ws.11))may fail. Microsoft is working on a solution; in the meantime, the company posted the following mitigations:

1. Uncheck the "Run in logged-on user's security context (user policy option)." Note: this might not mitigate the issue for items using a wildcard (\*).
2. Within the affected Group Policy, change "Action" from "Replace" to "Update."
3. If a wildcard (\*) is used in the location or destination, deleting the trailing "\" (backslash, without quotes) from the destination might allow the copy to be successful.

## **Major revisions**

So far, Microsoft has not published any major revisions to its security advisories.

## **Mitigations and workarounds**

There are two mitigations and four work-arounds for this October Patch Tuesday, including:

* [CVE-2022-41803](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41083): Visual Studio Code Elevation. Microsoft published a quick work-around for this security vulnerability that says: "Create a folder C:\ProgramData\jupyter\kernels\ and configure it to be writable only by the current user."
* [CVE-2022-22041](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22041): Windows Print Spooler Elevation. Microsoft's published work-around advice for managing this vulnerability is to stop the printer spooler service on the target machine using the following PowerShell commands, "Stop-Service -Name Spooler -Force, and Set-Service -Name Spooler -StartupType Disabled." This will stop the local print spooler on the machine and any printing services used by that system.

Microsoft has also noted that for the following reported network vulnerabilities, those systems are not affected if IPv6 is disabled and can be mitigated with the following PowerShell command: "Get-Service Ikeext:"

* [CVE-2022-37976](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-37976): Windows TCP/IP Driver Denial of Service Vulnerability;
* [CVE-2022-34721](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-34721): Windows Internet Key Exchange (IKE) Protocol Extensions;
* [CVE-2022-3471](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-34718), [CVE-2022-33645](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-33645)and [CVE-2022-34718](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-34718): Windows TCP/IP Remote Code Execution Vulnerability.

Each month, we break down the update cycle into product families (as defined by Microsoft) with the following basic groupings:

* Browsers (Microsoft IE and Edge);
* Microsoft Windows (both desktop and server);
* Microsoft Office;
* Microsoft Exchange;
* Microsoft Development platforms ( [ASP.NET](http://asp.net/)Core, .NET Core and Chakra Core);
* Adobe (retired???, maybe next year).

## **Browsers**

Microsoft released 18 updates to Edge (Chromium). Only[CVE-2022-41035](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41035) specifically applies to the browser, while the rest are Chromium related. You can find[this month's release note here](https://learn.microsoft.com/en-us/DeployEdge/microsoft-edge-relnotes-security). These are low profile, non-critical patches to Microsoft’s latest browser; they can be added to your standard release schedule.

## **Windows**

Microsoft delivers patches for 10 critical and 57 important vulnerabilities that cover the following feature groups in the Windows platform:

* Windows Networking (DNS, TLS, remote access and the TCP/IP stack);
* Cryptography (IKE extensions and Kerberos);
* Printing (again);
* Microsoft COM and OLE DB;
* Remote Desktop (Connection Manager and APIs).

One COM+ object-related vulnerability ([CVE-2022-41033](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41033)) has been reported as exploited in the wild. This makes things tough for patch and update deployment teams. Testing COM objects is generally difficult due to the business logic required and contained within the application. Also, determining which applications depend on this feature is not straightforward. This is especially the case for in-house developed or line-of-business applications due to business criticality. We recommend assessing, isolating, and testing core business apps that have COM and OLE dB dependencies before a general deployment of the October update. Add this Windows update to your "Patch Now" schedule.

On the lighter side of things, Microsoft has released another[Windows 11 update video](https://www.microsoft.com/en-us/videoplayer/embed/RE59eNG?pid=ocpVideo1-innerdiv-oneplayer&maskLevel=20&market=en-us).

## **Microsoft Office**

This month we get two critical updates ([CVE-2022-41038](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41038)and [CVE-2022-38048](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-38048)) and four updates rated as important to the Microsoft Office platform. Unless you are managing multiple SharePoint servers, this is a relatively low-profile update, with no Preview Pane-based attack vectors and no reports of exploits in the wild. If you or your team experienced issues with Microsoft Outlook [crashing](https://support.microsoft.com/en-us/topic/outlook-closes-shortly-after-it-is-opened-2d32d880-70a0-4ee0-b1e9-9e920721abdd)(sorry, “closing”) last month, Microsoft has offers the following advice:

1. Sign out of Office;
2. Turn off Support Diagnostics;
3. Set the following registry key: [HKEY\_CURRENT\_USER\Software\Microsoft\Office\16.0\Outlook\Options\General] "DisableSupportDiagnostics"=dword:00000001;
4. Restart your system.

Given these changes and low-profile updates, we suggest that you add these Office patches to your standard release schedule.

## **Microsoft Exchange Server**

We should have started with the Microsoft Exchange updates this month. The critical remote-pcode execution vulnerabilities ([CVE-2022-41082](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41082)and [CVE-2022-41040](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41040)) in Exchange have been reported as exploited in the wild and have *not* been resolved with this security update. There are patches available, and they are official from Microsoft. However, these two updates to Microsoft Exchange Server do not fully fix the vulnerabilities.

The [Microsoft Exchange Team blog](https://techcommunity.microsoft.com/t5/exchange-team-blog/released-october-2022-exchange-server-security-updates/ba-p/3646263)makes this point explicitly in the middle of a release note:

*"The October 2022 SUs do not contain fixes for the zero-day vulnerabilities reported publicly on September 29, 2022 (CVE-2022-41040 and CVE-2022-41082). Please see this blog post to apply mitigations for those vulnerabilities. We will release updates for CVE-2022-41040 and CVE-2022-41082 when they are ready."*

Microsoft has published [mitigation advice](https://msrc-blog.microsoft.com/2022/09/29/customer-guidance-for-reported-zero-day-vulnerabilities-in-microsoft-exchange-server/)for these serious Exchange security issues, covering:

* [CVE-2022-41040](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41040): [Exchange Emergency Mitigation Service](https://learn.microsoft.com/en-us/exchange/exchange-emergency-mitigation-service?view=exchserver-2019)
* [CVE-2022-41082](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41082): [Disable Remote PowerShell for Exchange](https://learn.microsoft.com/en-us/answers/questions/1033895/disable-remote-powershell-for-exchange.html)

We recommend implementing both the URL and PowerShell mitigations for all your Exchange servers. Watch this space, as we will see an update from Microsoft in the upcoming week.

**Microsoft development platforms**

Microsoft has released four updates (all rated important) for Visual Studio and .NET. Though all four vulnerabilities ([CVE-2022-41032](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41032), [CVE-2022-41032](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41083), [CVE-2022-41034](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41034)and [CVE-2022-41083](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-41083)) have standard entries in the Microsoft Security Update Guide ([MSUG](https://msrc.microsoft.com/update-guide/releaseNote/2022-Oct)), the Visual Studio team has also published these [17.3 Release notes](https://devblogs.microsoft.com/visualstudio/visual-studio-2022-17-3-is-now-available/). (And, just like Windows 11, we even get a [video](https://devblogs.microsoft.com/visualstudio/visual-studio-2022-17-3-is-now-available/).) All four of these updates are low-risk, low-profile updates to the development platform. Add these to your standard developer release schedule.

## **Adobe (really just Reader)**

Adobe Reader has been updated ([APSB22-46](https://helpx.adobe.com/security/products/acrobat/apsb22-46.html)) to resolve six [memory related vulnerabilities](https://www.adobe.com/devnet-docs/acrobatetk/tools/ReleaseNotesDC/continuous/dccontinuousoct2022.html#dccontinuousocttwentytwentytwo). With this release, Adobe has also updated release documentation to include [Known Issues](https://helpx.adobe.com/acrobat/kb/known-issues-acrobat-dc-reader.html)and planned [Release Notes](https://www.adobe.com/devnet-docs/acrobatetk/tools/ReleaseNotesDC/continuous/dccontinuousoct2022.html#dccontinuousocttwentytwentytwo). These notes cover both Windows and MacOS and both versions of Reader (DC and Continuous). All six reported vulnerabilities have the lowest Adobe rating, 3, which Adobe helpfully offers the following patch advice for: "Adobe recommends administrators install the update at their discretion."

We agree — add these Adobe Reader updates to your standard patch deployment schedule.





## Tags:
***CVE's***: CVE-2022-41082 CVE-2022-41033 CVE-2022-41035 CVE-2022-38048 CVE-2022-34718 CVE-2022-22041 CVE-2022-41083 CVE-2022-34721 CVE-2022-41034 CVE-2022-3471 CVE-2022-41803 CVE-2022-41038 CVE-2022-41040 CVE-2022-41032 CVE-2022-33645 CVE-2022-37976

### Autogenerated tags:
[[microsoft]] [[windows]] [[mitigations]] [[powershell]] [[cve-2022-41040]] [[vpn]] [[sharepoint]] [[tcp/ip]] [[low-profile]] [[cve-2022-41082]]
