# How to Use Threat Intelligence Feeds for SOC/DFIR Teams
## Threat intelligence feeds provide real-time updates on indicators of compromise (IOCs), such as malicious IPs and URLs.
## Information:

+ Link: https://cybersecuritynews.com/?p=64763
+ Source: Cyber Security News
+ Author: Kaaviya Ragupathy
+ Date published: 17 May 2024, 16:11
+ Date scraped: 17 May 2024, 17:12

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEi30Ih7v312qzzpNvAGR8O5GsfE4cyZ5RHyggMQLSKE4PciaaU7_Lh6pBTyAgKzdB6H50Shl26fg-SV6jNEX3b0tPXpvJQJzOLNWi0chO8xOcJ_lac2qh3QSCQQZeBOr6_7a-6NKT3VOKm0vKwaf5LTKoOQ5qTVzYE1m6oI2DdnTXWQ91kF96z8QVPn3PNi/s16000/Threat%20intelligence%20lookup.webp)


Threat intelligence feeds provide real-time updates on indicators of compromise (IOCs), such as malicious IPs and URLs.


Security researchers and organizations share IOCs with feed vendors, who then analyze and validate them before distributing the information to subscribers.


Security systems can then ingest these **[IOCs](https://cybersecuritynews.com/any-run-threat-intelligence-lookup/)** to identify and block potential threats, which essentially grants organizations immunity to the attacks identified by the IOCs.  


Commercial **[threat intelligence feeds](https://intelligence.any.run/plans/?utm_source=linkedin_csn&utm_medium=post&utm_campaign=birthday2024_scn&utm_content=plans&utm_term=200524)** provide curated threat data collected and processed by security vendors, which is often more specific and reliable (fewer false positives) due to proprietary methods and unique sources. 



![](https://lh7-us.googleusercontent.com/YB-1nYn2NWRcGSs1s_2SfWV1qUg3VQj7VK6v3vWxsmhw0mxe0pBJS80xItuyKARXVgj--RAGawpAYgwrjDNIOlRtXkr8hZi4W6pZ_f18xzNofcpVVM1wwEU5Mj4eQ9ZbPPH6MYhGvW1K)Indicators


The feeds enrich indicators with links to the corresponding sandbox analysis sessions, enabling security professionals to directly observe threat behavior within a controlled environment.


Open source threat intelligence (TI) feeds offer a vast amount of community-sourced threat data, potentially exceeding commercial offerings, as accuracy might be lower due to the inherent limitations of relying on potentially unreliable contributor reporting.


Typically, non-profit or governmental organizations are in charge of managing these feeds, which centralize data from various sources and distribute it for increased security awareness.


Examples include DHS’s Automated Indicator Sharing, the FBI’s InfraGard Portal, Abuse.ch, SANS’ Internet Storm Center, and the Spamhaus Project.


Uses both commercial and open-source threat intelligence feeds to maximize threat coverage, whereas commercial feeds offer more relevant and timely threat data, while open-source feeds broaden overall coverage.


To avoid alert fatigue from excessive and potentially false positives, implement filtering based on source reputation, indicator age, and contextual details to ensure security teams prioritize and respond effectively to genuine threats.


Threat intelligence (TI) feeds deliver data in a standardized format called STIX (Structured Threat Information Expression), which ensures consistent data exchange across different vendors’ security systems.



![](https://lh7-us.googleusercontent.com/03eWLdoFNzEJONHyzgrbG6t15c8oqFq-097Mnzx5RH3gYa13hLqJEJouJlAk8TZTAn9jR-9l8JyDSD9vgabWxXqGcNb9RHd5X8mCiFF98egz-7K9COTtU62ZbJccNSE5pGSlmKenzCbF)Obtaining a API key


A STIX object typically includes details like the indicator type (e.g., IP address), its value, timestamps for creation and modification, references to external analysis (e.g., sandbox session), and threat labels.


According to **[ANY.RUN](https://app.any.run/plans/?utm_source=linkedin_csn&utm_medium=post&utm_campaign=birthday2024_scn&utm_content=plans&utm_term=200524/)**, it simplifies the integration of TI feeds into Security Information and Event Management (SIEM) or Threat Intelligence Platform (TIP) systems, requiring only an API key for setup.


**How to operationalize data from TI feeds**
--------------------------------------------


Leverage Security Information and Event Management (SIEM) and [**Threat Intelligence Platform**](https://intelligence.any.run/plans/?utm_source=linkedin_csn&utm_medium=post&utm_campaign=birthday2024_scn&utm_content=plans&utm_term=200524) (TIP) to maximize the value of Threat Intelligence (TI) feeds. 


As mentioned, TI feeds are typically ingested into SIEM and TIP systems.


* **SIEM systems:** Collect, analyze, and correlate security events from multiple sources; data from TI feeds helps to analyze these events better.
* **TIP systems:** Contextualize indicators and build them into threat objects to get a more holistic view of the attack, enabling better prioritization and decision-making.


Configure ingestion frequency based on data accuracy: prioritize real-time updates for high-fidelity commercial feeds, and schedule periodic updates for broader but noisier open-source feeds.


![](https://lh7-us.googleusercontent.com/8Pq_eavrvwSthH6GZOfO6dfyC0tVYlSyhDaZel9I_SwUz3pyLSGh071Jwq10tVptmJWShpCyedXJ441qdqvuw8TZTSrsj89FIJAZVFnmb3ouY8qeaCj15t4EK3OsVWpNXockaLrXCDwQ)Enrich the data you receive from feeds with additional context on a TIP platform such as OpenCTI.


Within the TIP, enrich indicators with additional context like Tactics, Techniques, and Procedures (TTPs) and malware scores to enhance threat prioritization and response decisions, which optimizes resource allocation by focusing on high-confidence indicators while maintaining broader threat visibility.


After enriching data from Threat Intelligence (TI) feeds, SIEM correlation rules are configured to analyze this data alongside logs from various sources.


The rules prioritize high-confidence indicators and look for combinations of suspicious elements like IP addresses, domains, and file hashes linked to known threats, which enable automatic responses based on threat severity, such as blocking malicious IPs or domains.


**Threat Intelligence Lookup – Search Parameters**
--------------------------------------------------


Here below, we have mentioned all the search parameters:


* Single IOC
* Logged event fields
* Detection details
* Combined search
* Wildcard queries


In their [**interactive malware sandbox**](https://any.run/demo/?utm_source=linkedin_csn&utm_medium=post&utm_campaign=birthday2024_scn&utm_content=plans&utm_term=200524), ANY.RUN gathers threat intelligence from 14,000 daily tasks carried out by a community of 300,000+ researchers.


Besides this, the security teams can analyze malware in a cloud environment, engaging with it directly to uncover samples that bypass automated detection.


![](https://lh7-us.googleusercontent.com/Pi-q-2vBBntSrdyZ9SMSBfHR5UrPa5RkEIhEmbG40Q0ssczbaCYAOlMyJkt7pQUGVs06Ut7D5YusCKF4R1SU0JwNTPqeQHO96YWXrcc9f3qgyO2B9P64T3ApU2byV7TwLjdSWYdFQAb9Wh26AyYisoU)Access to the latest IOCs from millions of sandbox tasks


Sandbox lets analysts inspect the malware for 20 minutes, which can handle up to 100MB files, and configure custom VPN, MITM Proxy, and FakeNet for Windows/Linux.


The real-time data it provides to IOCs makes it a top tool for malware analysts contributing to the Threat Intelligence Database.


![](https://lh7-us.googleusercontent.com/Y-BgAkeguLdLj3-TNjPdD0wrZO_f9s-nHzQ__Il5k61mprdMsSSra8qzjxz0pFc1MobURh3Nk3SkFRW8z6Uo9G3NwS7VaqmbN14jaYzFYZA6Nu6rB8YaCKXlxLzhYt7ZnWIc8Go0naahgwv5D04dKvU)Direct access to sandbox tasks


The sandbox of ANY.RUN seamlessly links with the Threat Intelligence Lookup. Not only that, but it also identifies an indicator and accesses the recorded sandbox session for real-life malware behavior insights.


ANY.RUN is a cloud-based malware sandbox for SOC and DFIR teams. With advanced features, 300,000 professionals can investigate incidents and streamline threat analysis.





## Tags:


### Autogenerated tags:
[[malware]] [[siem]] [[any.run]] [[real-time]] [[open-source]] [[teams]]
