# CISA emergency directive: Mitigate Ivanti zero-days immediately
## CISA issued this year's first emergency directive ordering Federal Civilian Executive Branch (FCEB) agencies to immediately mitigate two Ivanti Connect Secure and Ivanti Policy Secure zero-day flaws in response to widespread and active exploitation by multiple threat actors.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/cisa-emergency-directive-mitigate-ivanti-zero-days-immediately/
+ Source: Bleeping Computer
+ Author: Sergiu Gatlan
+ Date published: 19 January 2024, 14:25
+ Date scraped: 19 January 2024, 20:04

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2023/06/02/0_CISA.jpg)



CISA issued this year's first emergency directive ordering Federal Civilian Executive Branch (FCEB) agencies to immediately mitigate two Ivanti Connect Secure and Ivanti Policy Secure zero-day flaws in response to widespread and active exploitation by multiple threat actors.


This is an expected development, given that vulnerable Ivanti appliances are now [targeted in extensive attacks](https://www.bleepingcomputer.com/news/security/ivanti-connect-secure-zero-days-now-under-mass-exploitation/) chaining the CVE-2023-46805 authentication bypass and the CVE-2024-21887 command injection vulnerabilities [since December](https://www.bleepingcomputer.com/news/security/ivanti-warns-of-connect-secure-zero-days-exploited-in-attacks/), and the vendor has yet to release security patches.


When chained, the two Ivanti zero-days allow attackers to move laterally within a target's network, exfiltrate data, and establish persistent system access by deploying backdoors.


"CISA has determined these conditions pose an unacceptable risk to Federal Civilian Executive Branch (FCEB) agencies and require emergency action," the cybersecurity agency [said on Friday](https://www.cisa.gov/news-events/directives/ed-24-01-mitigate-ivanti-connect-secure-and-ivanti-policy-secure-vulnerabilities).


"This determination is based on widespread exploitation of vulnerabilities by multiple threat actors, the prevalence of the affected products in the federal enterprise, the high potential for a compromise of agency information systems, the impact of a successful compromise, and the complexity of the proposed mitigations."


**ED 24-01 required actions**
-----------------------------


As instructed by emergency directive ED 24-01, federal agencies now must promptly implement [Ivanti's publicly disclosed mitigation measures](https://forums.ivanti.com/s/article/KB-CVE-2023-46805-Authentication-Bypass-CVE-2024-21887-Command-Injection-for-Ivanti-Connect-Secure-and-Ivanti-Policy-Secure-Gateways?language=en_US) to block attack attempts.


The agencies are also required to use Ivanti's External Integrity Checker Tool and:


1. Immediately report indications of compromise to CISA through [central@cisa.dhs.gov](mailto:central@cisa.dhs.gov)
2. Remove compromised products from agency networks. Initiate incident analysis, preserve data from the compromised devices through the creation of forensic hard drive images, and hunt for indications of further compromise.
3. Bring a compromised product back into service, reset the device with the affected Ivanti solution software to factory default settings and remove the attack vector by applying [Ivanti's mitigations](https://forums.ivanti.com/s/article/KB-CVE-2023-46805-Authentication-Bypass-CVE-2024-21887-Command-Injection-for-Ivanti-Connect-Secure-and-Ivanti-Policy-Secure-Gateways?language=en_US).

To fully restore impacted appliances and bring them back into service, they have to follow [Ivanti's recovery instructions](https://forums.ivanti.com/s/article/Recovery-Steps-Related-to-CVE-2023-46805-and-CVE-2024-21887?language=en_US) and then:


* Revoke and reissue any stored certificates.
* Reset the admin enable password.
* Reset stored API keys.
* Reset the password of any local user defined on the gateway, including service accounts used for auth server configuration(s).
* Apply updates that address the two vulnerabilities referenced in this Directive to the affected products as they become available and no later than 48 hours following their release by Ivanti.
* One week after the issuance of this Directive, report to CISA (using the provided template) a complete inventory of all instances of Ivanti Connect Secure and Ivanti Policy Secure products on agency networks, including details on actions taken and results.

Threat monitoring service Shadowserver currently tracks [more than 16,200 ICS VPN appliances](https://dashboard.shadowserver.org/statistics/iot-devices/time-series/?date_range=7&vendor=pulse+secure&model=pulse+connect+secure+vpn&group_by=geo&style=stacked) exposed online, [over 4,700](https://dashboard.shadowserver.org/statistics/iot-devices/time-series/?date_range=7&vendor=pulse+secure&model=pulse+connect+secure+vpn&geo=US&group_by=geo&style=stacked) in the United States (Shodan also sees [almost 17,000](https://beta.shodan.io/search?query=html%3A%22welcome.cgi%3Fp%3Dlogo%22) Internet-exposed Ivanti ICS devices).


Shadowserver is also [monitoring](https://twitter.com/Shadowserver/status/1747544924118003744) the number of compromised Ivanti Connect Secure VPN instances worldwide and [exploitation attempts](https://dashboard.shadowserver.org/statistics/honeypot/time-series/?date_range=7&host_type=src&vendor=ivanti&group_by=vulnerability&style=stacked), with [more than 420 hacked devices](https://dashboard.shadowserver.org/statistics/combined/time-series/?date_range=other&d1=2024-01-16&d2=2024-01-18&source=compromised_website&tag=ivanti-connect-secure%2B&group_by=geo&style=stacked) spotted on January 18 alone.



![Compromised Ivanti appliances](https://www.bleepstatic.com/images/news/u/1109292/2024/Compromised%20Ivanti%20appliances.jpg)*Compromised Ivanti appliances (Shadowserver)*


Actively exploited to drop crypto-miners, malware
-------------------------------------------------


Threat intelligence company Volexity [says](https://www.volexity.com/blog/2024/01/18/ivanti-connect-secure-vpn-exploitation-new-observations/) that one of the attackers (a suspected Chinese state-backed threat group tracked as UTA0178 and UNC5221) has already backdoored over 2,100 Ivanti appliances using a GIFTEDVISITOR webshell variant.


While investigating these attacks, Mandiant [found five custom malware strains deployed on breached customers' systems](https://www.bleepingcomputer.com/news/security/ivanti-connect-secure-zero-days-exploited-to-deploy-custom-malware/) with the end goal of stealing credentials, deploying webshells, and additional malicious payloads.


The threat actor has been harvesting and stealing account and session data and more info from compromised networks.


Victims discovered so far include government and military departments worldwide, national telecom companies, defense contractors, technology companies, banking, finance, and accounting organizations, worldwide consulting outfits, and aerospace, aviation, and engineering firms.


They vary greatly in size and range from small businesses to some of the largest organizations worldwide, including multiple Fortune 500 companies from various industry sectors.


Attackers have also been seen by [Volexity](https://www.volexity.com/blog/2024/01/18/ivanti-connect-secure-vpn-exploitation-new-observations/) and [GreyNoise](https://www.greynoise.io/blog/ivanti-connect-secure-exploited-to-install-cryptominers) deploying XMRig cryptocurrency miners and Rust-based malware payloads still waiting for analysis.





## Tags:
***CVE's***: CVE-2024-21887 CVE-2023-46805
***email-adresses***: throughcentral@cisa.dhs.gov

### Autogenerated tags:
[[ivanti]] [[cisa]] [[shadowserver]] [[malware]]
