# CISA warns of actively exploited Linux privilege elevation flaw
## The U.S. Cybersecurity & Infrastructure Security Agency (CISA) has added two vulnerabilities in its Known Exploited Vulnerabilities (KEV) catalog, including a Linux kernel privilege elevation flaw.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/cisa-warns-of-actively-exploited-linux-privilege-elevation-flaw/
+ Source: Bleeping Computer
+ Author: Bill Toulas
+ Date published: 31 May 2024, 15:30
+ Date scraped: 31 May 2024, 20:02

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2022/03/31/CISA__headpic.jpg)



The U.S. Cybersecurity & Infrastructure Security Agency (CISA) has added two vulnerabilities in its Known Exploited Vulnerabilities (KEV) catalog, including a Linux kernel privilege elevation flaw.


The high-severity flaw tracked as [CVE-2024-1086](https://nvd.nist.gov/vuln/detail/CVE-2024-1086) was first disclosed on January 31, 2024, as a use-after-free problem in the netfilter: nf\_tables component, but was first introduced by a commit [in February 2014](https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=e0abdadcc6e1).


Netfilter is a framework provided by the Linux kernel that allows various networking-related operations, such as packet filtering, network address translation (NAT), and packet mangling.


The vulnerability is caused because the 'nft\_verdict\_init()' function allows positive values to be used as a drop error within the hook verdict, causing the 'nf\_hook\_slow()' function to execute a double free when NF\_DROP is issued with a drop error that resembles NF\_ACCEPT.


Exploitation of CVE-2024-1086 allows an attacker with local access to achieve privilege escalation on the target system, potentially gaining root-level access.


The issue was fixed via a commit [submitted in January 2024](https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=f342de4e2f33e0e39165d8639387aa6c19dff660), which rejects QUEUE/DROP verdict parameters, thus preventing exploitation.


The fix has been backported to multiple stable kernel versions as listed below:


* v5.4.269 and later
* v5.10.210 and later
* v6.6.15 and later
* v4.19.307 and later
* v6.1.76 and later
* v5.15.149 and later
* v6.7.3 and later

In late March 2024, a security researcher using the alias 'Notselwyn' published a [detailed write-up](https://pwning.tech/nftables/) and proof-of-concept (PoC) [exploit on GitHub](https://github.com/Notselwyn/CVE-2024-1086), showcasing how to achieve local privilege escalation by exploiting the flaw on Linux kernel versions between 5.14 and 6.6.


![Diagram](https://www.bleepstatic.com/images/news/u/1220909/2024/Software/08/diagram.png)


While most Linux distrobutions pushed out fixes fairly quickly, Red Hat [had not pushed out a fix](https://jonathanspw.com/posts/2024-03-31-dealing-with-cve-2024-1086/) until March, making it possible that threat actors used the public exploit on compromised systems.


CISA did not share specific details about how the vulnerability is exploited, but BleepingComputer has seen posts on hacking forums about the public exploits.


The cybersecurity agency has now given federal agencies [until June 20, 2024](https://www.cisa.gov/known-exploited-vulnerabilities-catalog), to apply the available patches.


If updating is not possible, admins are recommended to apply the following mitigations:


1. Blocklist 'nf\_tables' if it's not needed/actively used.
2. Restrict access to user namespaces to limit the attack surface.
3. Load the Linux Kernel Runtime Guard ([LKRG](https://github.com/lkrg-org/lkrg)) module (can cause instability)

The second flaw CISA [added on the KEV catalog](https://www.cisa.gov/news-events/alerts/2024/05/30/cisa-adds-two-known-exploited-vulnerabilities-catalog) this time, also setting the due date to June 20, is CVE-2024-24919, an information disclosure vulnerability [impacting VPN devices from Check Point](https://www.bleepingcomputer.com/news/security/check-point-releases-emergency-fix-for-vpn-zero-day-exploited-in-attacks/).


Following the vendor's disclosure and security update release for this flaw, researchers from Watchtowr Labs published their analysis, underlining that the vulnerability [is far worse](https://labs.watchtowr.com/check-point-wrong-check-point-cve-2024-24919/) than what Check Point's bulletin reflected.





## Tags:
***CVE's***: CVE-2024-24919 CVE-2024-1086

### Autogenerated tags:
[[linux]] [[cisa]]
