# Why user experience is essential to identity protection
## Organizations must strike a delicate balance between maximizing end-user protection and minimizing the security-related obstacles.
## Information:

+ Link: https://www.cybersecuritydive.com/news/user-experience-identity-protection/633376/
+ Source: CyberSecurity Dive
+ Author: Kapil Raina
+ Date published: 05 October 2022, 00:00
+ Date scraped: 07 October 2022, 21:00

## Article:
![Main article image](https://www.cybersecuritydive.com/imgproxy/shHzUNKVlS0nuCRvuNeD9LaSV8GF74pSSZL_AdAtzdQ/g:ce/rs:fill:770:364:0/bG9jYWw6Ly8vZGl2ZWltYWdlL0N5YmVyc2VjdXJpdHlfaGVhZGVyXzktMjItMjIuanBn.jpg)



Editor’s note: The following is a guest article from Kapil Raina, identity protection evangelist at CrowdStrike.



It is likely that in your effort to safeguard your company’s network, data and people, you are forgetting one huge variable in your identity protection strategy: human nature.


By failing to account for human behavior in planning and deployment, businesses unknowingly create security gaps that hackers can exploit.


With 80% of security breaches [leveraging identity-based attacks](https://www.crowdstrike.com/cybersecurity-101/identity-security/), organizations are now focusing their attention on protection of user and machine credentials, as well as the identity infrastructure (eg. Active Directory) itself.


Adversaries use stolen credentials to bypass defenses and masquerade as legitimate users. When identities are compromised, enterprises are exposed to threats that range from ransomware to the theft of personally identifiable information of employees and customers.


It is great to see organizations giving identity protection the attention it deserves. However, one area they need to face head-on is the clash between the complexities of identity protection and the human need to “make things simple.”


Organizations must strike a delicate balance between maximizing end-user protection and minimizing the security-related obstacles employees need to navigate in their day-to-day work.


Let’s take a look at how many times a person needs to establish their identity in a typical work day.


* First, you need to log on to your computer.
* Second, assuming you are working remotely, you will need to establish your identity to a VPN, which likely requires a multifactor authentication (MFA) step.
* If you have a single-sign-on (SSO), you will also need to go through a process similar to the VPN.


Remember, this is a typical use case.


Now, imagine if you don’t have SSO and need to log in to individual apps and databases. The number of password or MFA challenges (and associated business rules for triggering them) can be overwhelming.


By having workers go through multiple steps just to do their work, it is no surprise that people will often use the same [credentials across multiple accounts](https://services.google.com/fh/files/blogs/google_security_infographic.pdf) to make things easier for themselves. It’s just human nature. And constantly forcing MFA can lead to “MFA fatigue,” a scenario in which the legitimate user blindly accepts all MFA challenges without looking at the details.


In this case, an adversary compromises a legitimate credential and then, when the system challenges the actual user, the user accepts the challenge blindly. This enables the adversary to continue the attack — and bypass MFA controls.


The human inclination to keep things simple can quickly become a serious security risk for enterprises, especially with hackers stepping up their “[credential stuffing](https://www.ic3.gov/Media/News/2022/220818.pdf)” efforts.



Keep up with the story. Subscribe to the Cybersecurity Dive free daily newsletter




Email:





* Select user consent:




 By signing up to receive our newsletter, you agree to our
 [Terms of Use](https://www.industrydive.com/terms-of-use/) and
 [Privacy Policy](https://www.industrydive.com/privacy-policy/). You can unsubscribe at anytime.


Sign up
A valid email address is required.
Please select at least one newsletter.


 var siteName = 'Cybersecurity Dive' || null;
 if (siteName) {
 setupFormCallbackAndCreateFormIfSub(siteName, 'inline');
 }
 
 .subscriber-demographics-form {
 width: 100%;
 }
 
Hackers will use social engineering and phishing techniques to obtain people’s credentials and then use the stolen identities to penetrate corporate networks. And this attack surface can extend to an organization’s entire supply chain — leaving many opportunities for an adversary to succeed.


### **Reexamine identity security with a human eye**


As organizations invest in cybersecurity, an increasingly complex security stack can create several touchpoints where identities can be compromised due to human nature.


Here are a few key things security teams should keep in mind when designing an identity threat protection strategy that prioritizes security without sacrificing user experience:


#### **Understand how workers interact with your systems**


Are your workers going through unnecessary steps to access corporate resources they need to do their jobs? What is their technical expertise and access to support (office staff, field operations, factory operations, etc.)?


By reducing security hurdles employees must take, organizations enable them to more efficiently and securely do their jobs. This also reduces the temptation for employees to use risky, unauthorized workarounds.


#### **Reduce security complexity**


Employing simple policies and risk-based access controls can greatly enhance the user experience.


For example, solutions such as risk-based conditional access and adaptive authentication can adjust to a user’s risk profile without interrupting their workflow.


If a user’s normal behavior changes — for example, they begin to move systems or data — their risk profile rises, and they can be challenged to validate their identity.


If the person passes the challenge, then their risk profile can be readjusted without creating an additional burden for the security team.


Keep up with the story. Subscribe to the Cybersecurity Dive free daily newsletter




Email:





* Select user consent:




 By signing up to receive our newsletter, you agree to our
 [Terms of Use](https://www.industrydive.com/terms-of-use/) and
 [Privacy Policy](https://www.industrydive.com/privacy-policy/). You can unsubscribe at anytime.


Sign up
A valid email address is required.
Please select at least one newsletter.


 var siteName = 'Cybersecurity Dive' || null;
 if (siteName) {
 setupFormCallbackAndCreateFormIfSub(siteName, 'inline');
 }
 
 .subscriber-demographics-form {
 width: 100%;
 }
 

### 
 Read More in Strategy












[![Blue padlock made to resemble a circuit board and placed on binary computer code.](/imgproxy/wmWMHqDCgz-iJZfUEv-MGuSIkvkNtqB-ioaG210u1iY/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0RhdGFfcHJpdmFjeV9oZWFkZXIuanBn.jpg)](https://www.cybersecuritydive.com/news/multifactor-authentication-weaknesses/633399/)
Oct 05, 2022
[Multifactor authentication is not all it’s cracked up to be](https://www.cybersecuritydive.com/news/multifactor-authentication-weaknesses/633399/)



[![Padlock on credit cards and us dollars.](/imgproxy/_Q_uTfgCZP9ukN_K3edvSv1zcIHAHDJuFHaCHwX4TaY/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTUxOTE2NTA1Mi5qcGc.jpg)](https://www.cybersecuritydive.com/news/cybersecurity-productivity-software-tech-budgets/633253/)
Oct 04, 2022
[Security to take an outsized role in IT spending in 2023](https://www.cybersecuritydive.com/news/cybersecurity-productivity-software-tech-budgets/633253/)



[![Man standing with hands on table at table at a meeting with other people in professional setting.](/imgproxy/gCMxIatbusM4-F1-yo_PIX-EUzc_9f5wMYwQTuFTAqk/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTEzNDYxMjUyMzcuanBn.jpg)](https://www.cybersecuritydive.com/news/c-suite-threats-cybersecurity/633069/)
Sep 30, 2022
[C-suite, boards are prioritizing cybersecurity, but still expect increased threats](https://www.cybersecuritydive.com/news/c-suite-threats-cybersecurity/633069/)



[![African-American IT developer typing on keyboard with black and orange programming code on computer screen and laptop in contemporary office interior, copy space](/imgproxy/-pMBcCdysFGF9c8QqoAJwPnrayxg3ceYHRicc4RKUy4/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTEyNTU5MDUyMDEuanBn.jpg)](https://www.cybersecuritydive.com/news/cicd-strengthens-security/632947/)
Sep 29, 2022
[Google Cloud research links CI/CD to security prowess](https://www.cybersecuritydive.com/news/cicd-strengthens-security/632947/)



[![Cloud computing technology internet on binary code with abstract background. Cloud Service, Cloud Storage Concept. 3D render.](/imgproxy/gcqsGdF8lXRB_fzc4fuaStpZW0B3G1TxzAwd-ph3gdw/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTEzMzg3OTgxMTguanBn.jpg)](https://www.cybersecuritydive.com/news/cloud-security-incident/632868/)
Sep 28, 2022
[Most organizations had a cloud-related security incident in the past year](https://www.cybersecuritydive.com/news/cloud-security-incident/632868/)



[![Close-up Portrait of Software Engineer Working on Computer, Line of Code Reflecting in Glasses.](/imgproxy/yVjJZPO4bGquIm8-SeE02iZqDPrLFhYRwY8wz1xItDc/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTEzNTU2Mzg4MzQuanBn.jpg)](https://www.cybersecuritydive.com/news/cloud-cybersecurity-modernization-paradox/632750/)
Sep 27, 2022
[Cyber paradox: Security looms as obstacle and opportunity in cloud migration](https://www.cybersecuritydive.com/news/cloud-cybersecurity-modernization-paradox/632750/)



[![Cell phone or mobile service tower in forested area of West Virginia providing broadband service](/imgproxy/0Ahnf56E-SLdkUGm3BM3ac3o7FwwOJXSfwJfzqFXDvQ/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTEyODE3MDg3MDAuanBn.jpg)](https://www.cybersecuritydive.com/news/telecom-cloud-open-source-risks/632550/)
Sep 23, 2022
[How common telecom cyber risks snowball in cloud, open source](https://www.cybersecuritydive.com/news/telecom-cloud-open-source-risks/632550/)



[![Concept with expert setting up automated software on laptop computer.](/imgproxy/-rPEsrebXNqprcNw7y546j9B7s5I9M1XSgHj7TInWTs/g:ce/rs:fill:1200:648:1/bG9jYWw6Ly8vZGl2ZWltYWdlL0dldHR5SW1hZ2VzLTEzNTg4MzU0NTkuanBn.jpg)](https://www.cybersecuritydive.com/news/software-supply-chain-security-tactics/632445/)
Sep 22, 2022
[Organizations rapidly shift tactics to secure the software supply chain](https://www.cybersecuritydive.com/news/software-supply-chain-security-tactics/632445/)



[Want to see more stories in **Strategy**?
 

 Read More ➔](/topic/strategy/)




#### **Consider using a unified security platform**


Taking a platform approach can help protect your company’s network and resources with continuous risk-based verification of user access. This includes contractors, partners and vendors from managed and unmanaged endpoints, and extends protection across on-premises, cloud and legacy applications.


By automatically creating and correlating contextual risk-based information from all entities, you can easily enable secure access to your workforce without compromising productivity and reduce the attack surface by preventing lateral movement across the network.


Cybersecurity has historically been seen as an obstacle to user experience. Now, with people working remotely more than ever, it’s time for IT and security teams to accept the user experience has become an integral part of their cybersecurity strategy.





## Tags:


### Autogenerated tags:
[[mfa]] [[cybersecurity]] [[risk-based]] [[cloud]]
