# CISA adds Cisco ASA and FTD and CrushFTP VFS flaws to its Known Exploited Vulnerabilities catalog
## CISA adds Cisco ASA and FTD and CrushFTP VFS vulnerabilities to its Known Exploited Vulnerabilities catalog.
## Information:

+ Link: https://securityaffairs.com/162308/security/cisa-adds-cisco-asa-and-ftd-and-crushftp-vfs-flaws-to-its-known-exploited-vulnerabilities-catalog.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 25 April 2024, 20:17
+ Date scraped: 25 April 2024, 21:07

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2020/07/CISA.jpeg)



The U.S. Cybersecurity and Infrastructure Security Agency (CISA) [added](https://www.cisa.gov/news-events/alerts/2024/04/24/cisa-adds-three-known-exploited-vulnerabilities-catalog) the following vulnerabilities to its [Known Exploited Vulnerabilities (KEV) catalog](https://www.cisa.gov/known-exploited-vulnerabilities-catalog):


* [CVE-2024-20353](https://nvd.nist.gov/vuln/detail/CVE-2024-20353) Cisco ASA and FTD Denial of Service Vulnerability
* [CVE-2024-20359](https://nvd.nist.gov/vuln/detail/CVE-2024-20359) Cisco ASA and FTD Privilege Escalation Vulnerability
* [CVE-2024-4040](https://nvd.nist.gov/vuln/detail/CVE-2024-4040) CrushFTP VFS Sandbox Escape Vulnerability


Cisco Talos this week [**warned**](https://securityaffairs.com/162244/apt/nation-state-actors-exploited-two-zero-days-in-asa-and-ftd-firewalls-to-breach-government-networks.html) that the nation-state actor UAT4356 (aka STORM-1849) has been exploiting two zero-day vulnerabilities in Adaptive Security Appliance (ASA) and Firepower Threat Defense (FTD) firewalls since November 2023 to breach government networks worldwide.



Cisco Talos researchers tracked this cyber-espionage campaign as ArcaneDoor.


Early in 2024, a customer contacted Cisco to report a suspicious related to its Cisco Adaptive Security Appliances (ASA). PSIRT and Talos launched an investigation to support the customer.


The experts discovered that the UAT4356 group deployed two backdoors, respectively called “Line Runner” and “Line Dancer.”


Cisco reported that the sophisticated attack chain employed by the attackers impacted a small set of customers. The experts have yet to identify the initial attack vector, however, they discovered the threat actors exploited two vulnerabilities ([CVE-2024-20353](https://sec.cloudapps.cisco.com/security/center/content/CiscoSecurityAdvisory/cisco-sa-asaftd-websrvs-dos-X8gNucD2) (denial of service) and [CVE-2024-20359](https://sec.cloudapps.cisco.com/security/center/content/CiscoSecurityAdvisory/cisco-sa-asaftd-persist-rce-FLsNXF4h) (persistent local code execution)) as zero-days in these attacks.


The Line Dancer in-memory implant that acts as a memory-resident shellcode interpreter that allows adversaries to execute arbitrary shellcode payloads. On compromised ASA devices, attackers utilize the host-scan-reply field to deliver shellcode, bypassing the need for [CVE-2018-0101](https://securityaffairs.com/68959/hacking/cve-2018-0101-cisco-asa-flaw.html) exploitation. By redirecting the pointer to the Line Dancer interpreter, attackers can interact with the device through POST requests without authentication. Threat actors used Line Dancer to execute various commands, including disabling syslog, extracting configuration data, generating packet captures, and executing CLI commands. Additionally, Line Dancer hooks into the crash dump and AAA processes to evade forensic analysis and establish remote access VPN tunnels.


The Line Runner allows attackers to maintain persistence on compromised ASA devices. It exploits a legacy capability related to VPN client pre-loading, triggering at boot by searching for a specific file pattern on disk0:. Upon detection, it unzips and executes a Lua script, providing persistent HTTP-based backdoor access. This backdoor survives reboots and upgrades, allowing threat actors to maintain control. Additionally, the Line Runner was observed retrieving staged information facilitated by the Line Dancer component.


The third issue added to the KEV catalog is a [CrushFTP](https://securityaffairs.com/162067/hacking/crushftp-zero-day-exploited.html) VFS sandbox escape vulnerability.


CrushFTP is a file transfer server software that enables secure and efficient file transfer capabilities. It supports various features such as FTP, SFTP, FTPS, HTTP, HTTPS, WebDAV, and WebDAV SSL protocols, allowing users to transfer files securely over different networks. CrushFTP also provides support for automation, scripting, user management, and extensive customization options meet the diverse needs of businesses and organizations.


In April, CrushFTP [notified](https://securityaffairs.com/162067/hacking/crushftp-zero-day-exploited.html) users of a virtual file system escape vulnerability impacting their FTP software, which could potentially enable users to download system files.


Simon Garrelou from the Airbus CERT discovered the vulnerability.


Crowdstrike researchers discovered that threat actors exploited the critical zero-day vulnerability in targeted attacks in the wild.


*“On April 19, 2024, CrushFTP advised of a virtual file system escape present in their FTP software that could allows users to download system files. Falcon OverWatch and Falcon Intelligence have observed this exploit being used in the wild in a targeted fashion.” reads a [**post**](https://www.reddit.com/r/crowdstrike/comments/1c88788/situational_awareness_20240419_crushftp_virtual/) published by Crowdstrike on Reddit.*


According to [Binding Operational Directive (BOD) 22-01: Reducing the Significant Risk of Known Exploited Vulnerabilities](https://cyber.dhs.gov/bod/22-01/), FCEB agencies have to address the identified vulnerabilities by the due date to protect their networks against attacks exploiting the flaws in the catalog.


Experts recommend also private organizations review the [Catalog](https://www.cisa.gov/known-exploited-vulnerabilities-catalog) and address the vulnerabilities in their infrastructure.


CISA orders federal agencies to fix this vulnerability by May 1st, 2024.


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [Mastodon](https://infosec.exchange/@securityaffairs)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, CISA)**




---




---





## Tags:
***CVE's***: CVE-2024-20353 CVE-2018-0101 CVE-2024-4040 CVE-2024-20359

### Autogenerated tags:
[[crushftp]] [[cisa]] [[ftd]] [[talos]] [[shellcode]] [[ftp]]
