# CISA orders federal agencies to disconnect Ivanti VPN instances by February 2
## CISA is ordering federal agencies to disconnect Ivanti Connect Secure and Ivanti Policy Secure products within 48 hours.
## Information:

+ Link: https://securityaffairs.com/158456/security/cisa-order-fix-ivanti-vpn.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 01 February 2024, 19:46
+ Date scraped: 01 February 2024, 21:01

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2020/07/CISA.jpeg)


For the first time since its establishment, CISA is ordering federal agencies to disconnect all instances of Ivanti Connect Secure and Ivanti Policy Secure products within 48 hours.


The CISA’s emergency directive orders to disconnect all instances no later than 11:59PM on Friday February 2, 2024.



*“As soon as possible and no later than 11:59PM on Friday February 2, 2024, disconnect all instances of Ivanti Connect Secure and Ivanti Policy Secure solution products from agency networks.” [reads the directive](https://www.cisa.gov/news-events/directives/supplemental-direction-v1-ed-24-01-mitigate-ivanti-connect-secure-and-ivanti-policy-secure).*




The government agency recommends continuing to look for indicators of compromise on any systems connected to—or recently connected to—the affected Ivanti device.


The government experts also ordered to monitor the authentication or identity management services that could be exposed and urged to isolate the systems from any enterprise resources to the greatest degree possible. CISA also warned to continue to audit privilege-level access accounts.


“To bring a product back into service, agencies are required to perform the following actions:


1. Export configuration settings.
2. Complete a factory reset per [Ivanti’s instructions](https://forums.ivanti.com/s/article/Recovery-Steps-Related-to-CVE-2023-46805-and-CVE-2024-21887?language=en_US).
3. Rebuild the device per Ivanti’s instructions AND upgrade to one of the following supported software versions through [Ivanti’s download portal](https://www.ivanti.com/resources/downloads) (there is no cost to upgrade): 9.1R18.3, 22.4R2.2, 22.5R1.1, 9.1R14.4, 9.1R17.2.”


IVANTI recently warned of four zero-days, three of which are actively exploited in the wild.


In early January, the software firm [reported](https://securityaffairs.com/157306/hacking/ivanti-connect-secure-policy-secure-0days.html) that threat actors are exploiting two zero-day vulnerabilities (CVE-2023-46805, CVE-2024-21887) in Connect Secure (ICS) and Policy Secure to remotely execute arbitrary commands on targeted gateways.


The flaw CVE-2023-46805 (CVSS score 8.2) is an Authentication Bypass issue that resides in the web component of Ivanti ICS 9.x, 22.x and Ivanti Policy Secure. A remote attacker can trigger the vulnerability to access restricted resources by bypassing control checks.


The second flaw, tracked as CVE-2024-21887 (CVSS score 9.1) is a command injection vulnerability in web components of Ivanti Connect Secure (9.x, 22.x) and Ivanti Policy Secure. An authenticated administrator can exploit the issue by sending specially crafted requests and execute arbitrary commands on the appliance.


An attacker can chain the two flaws to send specially crafted requests to unpatched systems and execute arbitrary commands.


*“If CVE-2024-21887 is used in conjunction with CVE-2023-46805, exploitation does not require authentication and enables a threat actor to craft malicious requests and execute arbitrary commands on the system.” reads the [advisory](https://forums.ivanti.com/s/article/CVE-2023-46805-Authentication-Bypass-CVE-2024-21887-Command-Injection-for-Ivanti-Connect-Secure-and-Ivanti-Policy-Secure-Gateways?language=en_US) published by Ivanti.*


This week Ivanti [warned](https://securityaffairs.com/158403/hacking/ivanti-actively-exploited-zero-day-cve-2024-21893.html) of two new high-severity vulnerabilities in its Connect Secure and Policy Secure solutions respectively tracked as CVE-2024-21888 (CVSS score: 8.8) and CVE-2024-21893 (CVSS score: 8.2). The software company also warned that one of these two vulnerabilities is under active exploitation in the wild.


The vulnerability CVE-2024-21888 is a privilege escalation issue that resides in the web component of Ivanti Connect Secure (9.x, 22.x) and Policy Secure (9.x, 22.x). An attacker can exploit the vulnerability to gain admin privileges.


The second flaw CVE-2024-21893 is a server-side request forgery vulnerability in the SAML component of Connect Secure (9.x, 22.x), Policy Secure (9.x, 22.x) and Neurons for ZTA. An authenticated attacker can exploit the issue to access certain restricted resources.


The company also warns that the situation is still evolving and multiple threat actors can rapidly adapat their tactics, techniques, and procedures to exploit these issues in their campaigns.


*“At the time of publication, the exploitation of CVE-2024-21893 appears to be targeted. Ivanti expects the threat actor to change their behavior and we expect a sharp increase in exploitation once this information is public – similar to what we observed on 11 January following the 10 January disclosure.” [reads the advisory](https://forums.ivanti.com/s/article/KB-CVE-2023-46805-Authentication-Bypass-CVE-2024-21887-Command-Injection-for-Ivanti-Connect-Secure-and-Ivanti-Policy-Secure-Gateways?language=en_US).*


*“Be aware that the situation is still evolving. Ivanti will update this knowledge base article as more information becomes available.”*


The software firm recommends importing the “mitigation.release.20240126.5.xml” file via the download portal as temporary workarounds to address CVE-2024-21888 and CVE-2024-21893.


Mandiant researchers recently [discovered](https://securityaffairs.com/158440/apt/malware-ivanti-vpn-flaws-attacks.html) new malware employed by a China-linked APT group known as UNC5221 and other threat groups targeting [Ivanti Connect Secure VPN and Policy Secure](https://securityaffairs.com/157306/hacking/ivanti-connect-secure-policy-secure-0days.html) devices.


The cybersecurity firm reported that threat actors are employing the malware in post-exploitation activity, likely performed through automated methods.


Mandiant recently observed a mitigation bypass technique used to deploy a custom web shell tracked as [BUSHWALK](https://advantage.mandiant.com/malware/malware--96732cf0-d99a-501b-9646-c49f2b30dd5a). Successful exploitation would bypass the initial mitigation provided by Ivanti on Jan. 10, 2024.


Mandiant speculates that mitigation bypass activity is highly targeted, restricted, and differs from the [mass exploitation activity](https://securityaffairs.com/158393/malware/ivanti-connect-secure-vpn-deliver-krustyloader.html) observed after the disclosure of the Ivanti flaws.


Other malware employed in the attack is a new variant of the [LIGHTWIRE](https://advantage.mandiant.com/malware/malware--089bf6cc-9b67-5bd5-8fd3-3330e7cedf7e) web shell, the Python web shell backdoor [CHAINLINE](https://advantage.mandiant.com/malware/malware--4a3560fd-5ec5-5581-a8f7-1c888d28186b) and [FRAMESTING](https://advantage.mandiant.com/malware/malware--30efd16a-3713-5899-b45a-50faff982887) web shell.


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking,** **IVANTI**)





---




---





## Tags:
***CVE's***: CVE-2024-21887 CVE-2024-21888 CVE-2023-46805 CVE-2024-21893

### Autogenerated tags:
[[ivanti]] [[9.x]] [[22.x]] [[cvss]] [[cve-2024-21893]] [[cisa]] [[cve-2023-46805]] [[cve-2024-21887]] [[cve-2024-21888]] [[mandiant]]
