# Thousands of Citrix servers still vulnerable to CVE-2022-27510 and CVE-2022-27518
## Researchers warn of thousands of Citrix Application Delivery Controller (ADC) and Gateway endpoints are still unpatched. NCC Group’s Fox-IT research team warns of thousands of Citrix ADC and Gateway endpoints remain vulnerable to two critical vulnerabilities, tracked as CVE-2022-27510 and CVE-2022-27518 (CVSS scores: 9.8), that the company addressed in recent months. CVE-2022-27510 flaw is an authentication bypass using an […]
## Information:

+ Link: https://securityaffairs.com/140112/hacking/citrix-servers-vulnerable-online.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 29 December 2022, 14:35
+ Date scraped: 29 December 2022, 16:00

## Article:
![Main article image](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2022/12/citrix-versions-by-country.png?resize=300%2C300&ssl=1)


NCC Group’s Fox-IT research team warns of thousands of Citrix ADC and Gateway endpoints remain vulnerable to two critical vulnerabilities, tracked as [CVE-2022-27510](https://securityaffairs.com/138264/security/citrix-gateway-adc-flaws.html) and [CVE-2022-27518](https://securityaffairs.com/139609/apt/citrix-adc-gateway-cve-2022-27518.html) (CVSS scores: 9.8), that the company addressed in recent months.


CVE-2022-27510 flaw is an authentication bypass using an alternate path or channel. An attacker can trigger it to gain unauthorized access to Gateway user capabilities. The vendor pointed out that only appliances that are operating as a Gateway (appliances using the SSL VPN functionality or deployed as an ICA proxy with authentication enabled) are impacted.


Citrix addressed the flaw on November 8, 2022.


The CVE-2022-27518 flaw is a remote code execution bug that can be exploited by an unauthenticated, remote attacker to gain arbitrary code execution on the vulnerable appliance.


On December 13, the vendor urged administrators to apply security updates for the zero-day vulnerability in ADC and Gateway that was actively exploited by China-linked threat actors to gain access to target networks.


Now researchers at NCC Group’s Fox IT team reported despite most internet-facing endpoints have been updated to versions that fix both issues, thousands of installs remain vulnerable.


The researchers initially scanned the Internet for Citrix servers and found around 28.000 installs as of November 11, 2022.


Unfortunately, the version number of these installs was not included in the HTTP response from the servers. The experts noticed that there is an MD5 hash-like value in the HTTP body when requesting the URL:


`/vpn/index.html` 


Then they downloaded and deployed all Citrix ADC versions from cloud marketplaces, including Google Cloud Marketplace, AWS, Azure, and Citrix, and analyzed the matches between hashes and versions.


The research team noticed that some hashes could not be matched with the versions obtained with the described process, then analyzed the build date to deduce their versions.


The following graph shows the Top 20 active versions on the internet as of December 28, 2022, and reports if those versions are vulnerable to both issues:



[![citrix versions](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2022/12/citrix-versions.png?resize=491%2C349&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2022/12/citrix-versions.png?ssl=1)


The good news is that the majority of the servers, more than 5,000, are running the 13.0-88.14 version that’s not impacted by the two flaws.


Over 3,500 Citrix ADC and Gateway servers are running the 12.1-65.21 version which is vulnerable to CVE-2022-27518 attacks, while more than 500 servers are running the 12.1-63.22 version which is vulnerable to both critical flaws.


This second graph shows the Top 20 countries using Citrix ADC / Gateway and how many of them are still vulnerable.



[![citrix versions by country](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2022/12/citrix-versions-by-country.png?resize=499%2C345&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2022/12/citrix-versions-by-country.png?ssl=1)


In China, only 20% of internet-facing servers have been updated against both issues.


*“In this blog, we’ve shown how we performed the version identification of Citrix ADC and Citrix Gateway servers by analysing disk images exported from Google Cloud Marketplace using `dissect`. We also demonstrated that gzip files can be helpful for timestamp information and how we utilised this to find and download missing Citrix ADC builds.” [concludes the report](https://blog.fox-it.com/2022/12/28/cve-2022-27510-cve-2022-27518-measuring-citrix-adc-gateway-version-adoption-on-the-internet/). “Finally, we used the [version identification data](https://gist.github.com/fox-srt/c7eb3cbc6b4bf9bb5a874fa208277e86) to measure the versions of internet-facing Citrix ADC and Gateway servers over time and see that the [NSA](https://media.defense.gov/2022/Dec/13/2003131586/-1/-1/0/CSA-APT5-CITRIXADC-V1.PDF) and [Citrix advisory](https://www.citrix.com/blogs/2022/12/13/critical-security-update-now-available-for-citrix-adc-citrix-gateway/) really helped with updates. However, some servers remain vulnerable to [CVE-2022-27510](https://support.citrix.com/article/CTX463706/citrix-gateway-and-citrix-adc-security-bulletin-for-cve202227510-cve202227513-and-cve202227516) or [CVE-2022-27518](https://support.citrix.com/article/CTX474995/citrix-adc-and-citrix-gateway-security-bulletin-for-cve202227518). We hope this blog creates extra awareness for these two Citrix CVEs and that our research on version identification contributes to future studies.”*


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)




|  |  |
| --- | --- |
|  |  |




[**Pierluigi Paganini**](https://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](https://securityaffairs.co/wordpress/)**–** **hacking, Citrix)**





  


---


  




## Tags:
***CVE's***: CVE-2022-27510 CVE-2022-27518

### Autogenerated tags:
[[citrix]] [[cve-2022-27518]] [[cve-2022-27510]] [[internet-facing]] [[cloud]]
