# Threat actors target govt networks exploiting Fortinet SSL-VPN CVE-2022-42475 bug
## Recently patched Fortinet FortiOS SSL-VPN zero-day exploited in attacks against government organizations and government-related targets. Fortinet researchers reported that threat actors exploited the recently patched FortiOS SSL-VPN vulnerability (CVE-2022-42475) in attacks against government organizations and government-related targets. In December, the security vendor urged its customers to update their installs to address an actively exploited FortiOS SSL-VPN […]
## Information:

+ Link: https://securityaffairs.com/140721/hacking/fortinet-ssl-vpn-cve-2022-42475-attacks.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 13 January 2023, 05:46
+ Date scraped: 13 January 2023, 07:00

## Article:
![Main article image](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2019/11/fortinet-logo.jpg?resize=300%2C300&ssl=1)


Fortinet researchers reported that threat actors exploited the recently patched FortiOS SSL-VPN vulnerability ([CVE-2022-42475](https://securityaffairs.com/139569/hacking/fortinet-fortios-ssl-vpn-bug.html)) in attacks against government organizations and government-related targets.


In December, the security vendor [**urged**](https://securityaffairs.com/139569/hacking/fortinet-fortios-ssl-vpn-bug.html) its customers to update their installs to address an actively exploited FortiOS SSL-VPN vulnerability, tracked as CVE-2022-42475, that could be exploited by an unauthenticated, remote attacker to execute arbitrary code on devices.


The security flaw ([CVE-2022-42475](https://nvd.nist.gov/vuln/detail/CVE-2022-42475)) abused in these incidents is a heap-based buffer overflow weakness found in the FortiOS SSLVPNd that allowed unauthenticated attackers to crash targeted devices remotely or gain remote code execution.


The CVE-2022-42475 flaw is a heap-based buffer overflow issue that resides in FortiOS sslvpnd.


*“A heap-based buffer overflow vulnerability [CWE-122] in FortiOS SSL-VPN may allow a remote unauthenticated attacker to execute arbitrary code or commands via specifically crafted requests.” reads the [advisory](https://www.fortiguard.com/psirt/FG-IR-22-398) published by the security vendor. “Fortinet is aware of an instance where this vulnerability was exploited in the wild,”*


Fortinet addressed the issue with the release of FortiOS 7.2.3.


According to the experts, the threat actor behind the attacks is a sophisticated attacker due to the complexity of the exploit. The attackers exploited the flaw to deliver a variant of a generic Linux implant customized for FortiOS.


The malicious binary was located at */data/lib/libips.bak*, attackers masquerade the malware as a component of Fortinet’s IPS Engine, located at /data/lib/libips.so. 


*“Libips.bak exports the functions ips\_so\_patch\_urldb and ips\_so\_query\_interface. These are the same exports in the clean IPS engine binary, libips.so. Both exported functions lead to the same malicious code. If libps.bak is named libips.so in the /data/lib directory, the malicious code will be executed automatically as components of FortiOS will call these exported functions.” reads the [report](https://www.fortinet.com/blog/psirt-blogs/analysis-of-fg-ir-22-398-fortios-heap-based-buffer-overflow-in-sslvpnd) published by Fortinet. “The binary does not attempt to return to the clean IPS engine code, so IPS functionality is also compromised.”*


Post-incident meta data investigation allowed the experts to uncover an additional IoC, the IP address 185[.]174[.]136[.]20. A folder on the server was containing binaries built specifically to target FortiGate hardware versions.


Then the researchers created a set of Yara rules to hunt for similar file samples and identified the **/var/w** samples. The execution of these files was observed in the PCAPs but not obtained directly from the file system.


The analysis of the **/var/w files** samples revealed that threat actors use advanced capabilities to manipulate FortiOS logging, such as:


* The malware patches the logging processesof FortiOS to manipulate logs to evade detection. – */bin/miglogd* & */bin/syslogd*
* It includes offsets and opcodes for 27 FortiGate models and version pairs. The malware opens a handle to the processes and injects data into them.
	+ Versions range from 6.0.5 to 7.2.1
	+ Models are FG100F, FG101F, FG200D, FG200E, FG201F, FG240D, FG3H0E, FG5H0E, FG6H1E, FG800D, FGT5HD, FGT60F, FGT80F.
* The malware can manipulate log files. It searches for elog files, which are logs of events in FortiOS. After decompressing them in memory, it searches for a string the attacker specifies, deletes it, and reconstructs the logs.
* The malware can also kill the logging processes.


A Windows samplea analyzed by the experts were compiled on a machine in the UTC+8 timezone, which includes Australia, China, Russia, Singapore, and other Eastern Asian countries.


*“The self-signed certificates created by the attackers were all created between 3 and 8 AM UTC. However, it is difficult to draw any conclusions from this given hackers do not nessesarily operate during office hours and will often operate during victim office hours to help obfuscate their activity with general network traffic.” concludes the report.*


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)




|  |  |
| --- | --- |
|  |  |




[**Pierluigi Paganini**](https://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](https://securityaffairs.co/wordpress/)**–** **hacking, Fortinet)**





  


---


  




## Tags:
***CVE's***: CVE-2022-42475
***urls***: http://185.174.136.20

### Autogenerated tags:
[[fortios]] [[fortinet]] [[malware]] [[cve-2022-42475]] [[ssl-vpn]] [[heap-based]]
