# Thousands of Palo Alto Firewalls Potentially Impacted by Exploited Vulnerability
## Shadowserver has identified roughly 6,000 internet-accessible Palo Alto Networks firewalls potentially vulnerable to CVE-2024-3400.
## Information:

+ Link: https://www.securityweek.com/thousands-of-palo-alto-firewalls-potentially-impacted-by-exploited-vulnerability/
+ Source: SecurityWeek
+ Author: Ionut Arghire
+ Date published: 22 April 2024, 11:55
+ Date scraped: 22 April 2024, 12:01

## Article:
![Main article image](https://www.securityweek.com/wp-content/uploads/2024/04/Palo-Alto-Networks.jpeg)


**There are roughly 6,000 internet-accessible Palo Alto Networks firewalls potentially affected by a recently addressed exploited vulnerability, the Shadowserver Foundation reports.**


Palo Alto Networks [disclosed](https://www.securityweek.com/palo-alto-networks-warns-of-exploited-firewall-vulnerability/) the flaw on April 12 and started [rolling out patches](https://www.securityweek.com/palo-alto-networks-releases-fixes-for-firewall-zero-day-as-first-attribution-attempts-emerge/) a couple of days later. The issue had been targeted by state-sponsored threat actors and its [exploitation surged](https://www.securityweek.com/exploitation-of-palo-alto-firewall-vulnerability-picking-up-after-poc-release/) last week, as proof-of-concept (PoC) code was published.


The issue, tracked as CVE-2024-3400 (CVSS score of 10/10), is described as a command injection in the GlobalProtect feature of PAN-OS, the operating system running on Palo Alto Networks’ appliances.

According to the vendor’s updated advisory, the flaw is rooted in an arbitrary file creation defect and, under specific conditions, can be exploited without authentication to execute arbitrary code with root privileges on a vulnerable firewall.

Initially, Palo Alto Networks said that only appliances with the GlobalProtect gateway feature configured and device telemetry enabled are vulnerable, and recommended disabling device telemetry as a mitigation.

The revised version of [the advisory](https://security.paloaltonetworks.com/CVE-2024-3400), however, removes the device telemetry mentions and points out that disabling the feature is no longer considered an effective mitigation.


“Device telemetry does not need to be enabled for PAN-OS firewalls to be exposed to attacks related to this vulnerability,” the vendor notes.

In an April 19 [blog post](https://www.paloaltonetworks.com/blog/2024/04/more-on-the-pan-os-cve/), Palo Alto Networks explained that CVE-2024-3400 was rooted in two PAN-OS flaws leading to unauthenticated remote shell command execution when combined.


The first bug existed because the GlobalProtect service failed to sufficiently validate the session ID format before storage, allowing an attacker to send a crafted shell command and create an empty file with an embedded command as the filename.

The second issue was that the OS trusted that the file was system-generated, leading to a scheduled system job to use the filename in a command, thus executing the attacker-supplied command with elevated privileges.

While the successful exploitation of the first bug would only lead to the creation of an empty file with a specific filename, the exploitation of the second would allow attackers to steal sensitive information or deploy malware.

“A highly sophisticated threat actor discovered that by uniquely combining the two bugs, they could perform a two-stage attack to achieve command execution on the vulnerable device,” Palo Alto Networks says.

The vendor recommended disabling device telemetry as it prevented the system cron job from running, thus preventing the command execution, but later discovered additional methods of exploiting CVE-2024-3400 that did not require telemetry to be enabled.

“The fix effectively removes the two problems in code that enabled this vulnerability to manifest. First, the session IDs are sufficiently validated before being stored. Then, the code that enabled command injection was rewritten using defensive programming techniques,” Palo Alto Networks says.

The company also notes that Threat Prevention signatures released on April 11 could fully block all known suspicious patterns in session IDs, and that roughly 90% of its customers have applied the mitigation.

On Friday, Shadowserver Foundation [said](https://twitter.com/Shadowserver/status/1781246114089390292) it had observed more than 22,000 potentially vulnerable Palo Alto Networks GlobalProtect instances connected to the internet. As of April 21, data from the security organization [shows](https://dashboard.shadowserver.org/statistics/combined/map/?map_type=std&day=2024-04-21&source=http_vulnerable&source=http_vulnerable6&tag=possible-cve-2024-3400%2B&geo=all&data_set=count&scale=log) roughly 6,000 potentially vulnerable instances.



![](https://www.securityweek.com/wp-content/uploads/2024/04/PAN-1024x485.png)


**Related:** [Thousands of Ivanti VPN Appliances Impacted by Recent Vulnerability](https://www.securityweek.com/thousands-of-ivanti-vpn-appliances-impacted-by-recent-vulnerability/)


**Related:**[Recent Fortinet FortiClient EMS Vulnerability Exploited in Attacks](https://www.securityweek.com/recent-fortinet-forticlient-ems-vulnerability-exploited-in-attacks/)


**Related:** [Recent Zero-Day Could Impact Up to 97,000 Microsoft Exchange Servers](https://www.securityweek.com/recent-zero-day-could-impact-up-to-97000-microsoft-exchange-servers/)





## Tags:
***CVE's***: CVE-2024-3400

### Autogenerated tags:
[[palo]] [[globalprotect]] [[cve-2024-3400]] [[pan-os]]
