# New TunnelVision Attack Allows Hijacking of VPN Traffic via DHCP Manipulation
## Researchers have uncovered a vulnerability (CVE-2024-3661) that allows threat actors to snoop on your VPN traffic.
## Information:

+ Link: https://thehackernews.com/2024/05/new-tunnelvision-attack-allows.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 09 May 2024, 23:25
+ Date scraped: 09 May 2024, 18:12

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhQlsUsoiYy4aXpmIuXau1TgGOZCD90EijcsFIeenHhC3SbZx0oCAUNX5BXImJJt4h30CotZ6v2szc7nwoa7K1DksiIAUboLQbvpH_7gBFvurgPQd2ANs1v9JieyCVRolbQ3_smQa-p7gM2krtcbqLr0kfuCMhvxGNCjgBb5YqCnTMcCO-PDA_7R96f3VF2/s728-rw-e365/vpn.png)


Researchers have detailed a Virtual Private Network (VPN) bypass technique dubbed **TunnelVision** that allows threat actors to snoop on victim's network traffic by just being on the same local network.


The "decloaking" [method](https://www.leviathansecurity.com/blog/tunnelvision) has been assigned the CVE identifier **[CVE-2024-3661](https://nvd.nist.gov/vuln/detail/CVE-2024-3661)** (CVSS score: 7.6). It impacts all operating systems that implement a DHCP client and has support for DHCP option 121 routes.


At its core, TunnelVision involves the routing of traffic without encryption through a VPN by means of an attacker-configured DHCP server using the [classless static route option 121](https://datatracker.ietf.org/doc/html/rfc3442) to set a route on the VPN user's [routing table](https://en.wikipedia.org/wiki/Routing_table).


It also stems from the fact the DHCP protocol, by design, does not authenticate such option messages, thus exposing them to manipulation.


DHCP is a client/server protocol that automatically provides an Internet Protocol (IP) host with its IP address and other related configuration information such as the subnet mask and default gateway so as to access the network and its resources.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiuUUskkMH9dUT3LF77_Q_irGuaE4LGjp-Am2Ls_UzGJ5EBnZHfuFiSvKs4OPE5KmfedBHcuZZVHS4Bh48UJx8brpwtg6Vr2Gepbaw-lGMIm9HjUhyphenhyphen2W5DVm5-ymwPS691Ie32TrCqFIv6SxNRA-jOKCKZrOB5dV7BfL0zVAhOO0neNkP9yv-XePBU1hN_0/s728-e365/wing-d.png)](https://thehackernews.uk/third-party-risk-management-saas)
It also helps reliably configure IP addresses via a server that maintains a pool of IP addresses and leases an address to any DHCP-enabled client when it starts up on the network.


Because these IP addresses are dynamic (i.e., leased) rather than static (i.e., permanently assigned), addresses that are no longer in use are automatically returned to the pool for reallocation.


The vulnerability, in a nutshell, makes it possible for an attacker with the ability to send DHCP messages to manipulate routes to redirect VPN traffic, thereby allowing them to read, disrupt, or possibly modify network traffic that was expected to be protected by the VPN.


"Because this technique is not dependent on exploiting VPN technologies or underlying protocols, it works completely independently of the VPN provider or implementation," Leviathan Security Group researchers Dani Cronce and Lizzie Moratti [said](https://www.tunnelvisionbug.com/).


"Our technique is to run a DHCP server on the same network as a targeted VPN user and to also set our DHCP configuration to use itself as a gateway. When the traffic hits our gateway, we use traffic forwarding rules on the DHCP server to pass traffic through to a legitimate gateway while we snoop on it."



In other words, TunnelVision tricks a VPN user into believing that their connections are secured and routed through an encrypted tunnel, when in reality it has been redirected to the attacker's server so that it can be potentially inspected.


However, in order to successfully decloak the VPN traffic, the targeted host's DHCP client must implement DHCP option 121 and accept a DHCP lease from the attacker-controlled server.


The attack is also similar to [TunnelCrack](https://thehackernews.com/2023/08/new-whiffy-recon-malware-triangulates.html), which is designed to leak traffic outside a protected VPN tunnel when connecting to an untrusted Wi-Fi network or a rogue ISP, resulting in adversary-in-the-middle (AitM) attacks.

 The problem affects all major operating systems like Windows, Linux, macOS, and iOS with the exception of Android as it does not have support for DHCP option 121. It also affects VPN tools that solely rely on routing rules to secure the host's traffic.


Mullvad has since [confirmed](https://mullvad.net/en/blog/evaluating-the-impact-of-tunnelvision) that the desktop versions of its software have firewall rules in place to block any traffic to public IPs outside the VPN tunnel, but acknowledged that the iOS version is vulnerable to TunnelVision. 


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg_WRs2jRYPNRPdVnIJ52g0Zo3TY_c0FSwk8ZZN085hqm-nXig4b7WIZCpqdHexadU4EmZ402vX1EghcAxIZGa9lwLkWAPPYzPbg1gc5UZCbvTtOHQ3ozwiQAgJ1ahKFoOp8SZl-JN8_URGwiu9aTe5U2wiVHGEetM-S7kKkmgPMNdL_83d5HTJrLm7iBp6/s728-e365/cis-d.png)](https://thehackernews.uk/cis-hardened-images)
However, it's yet to integrate and ship a fix owing to the complexity of the undertaking, which the Swedish company [said](https://mullvad.net/en/blog/response-to-tunnelcrack-vulnerability-disclosure) has been working on for "some time."


"The TunnelVision vulnerability (CVE-2024-3661) exposes a method for attackers to bypass VPN encapsulation and redirect traffic outside the VPN tunnel," Zscaler researchers [said](https://www.zscaler.com/blogs/security-research/cve-2024-3661-k-tunnelvision-exposes-vpn-bypass-vulnerability), describing it as a technique that employs a DHCP starvation attack to create a side-channel.


"This technique involves using DHCP option 121 to route traffic without encryption through a VPN, ultimately sending it to the internet via a side-channel created by the attacker."


To mitigate TunnelVision, organizations are recommended to implement DHCP snooping, ARP protections, and port security on switches. It's also advised to implement network namespaces on Linux to fix the behavior.


  





## Tags:
***CVE's***: CVE-2024-3661

### Autogenerated tags:
[[vpn]] [[dhcp]] [[tunnelvision]] [[ip]]
